@@ -26,8 +26,8 @@ f=f+('<option value="'+d[0]+'" '+(0==e?"selected":"")+">"+d[1]+"</option>");f=(f
 a[c].substring(0,4)+"')\">"+a[c].substring(0,4)+"</a></td>"),e.push("<td>"+a[c].split("Title>")[1].split("</")[0]+"</td></tr>");e.push("</table>");d=a.length-1+" matches";break;case "$":case ":":break;default:return}b._infoHeader=d;b._info=e.join("");b._showInfo(!0)};a._loadSuccess=function(b,f){f&&(a._ajaxDone(),f(b))};a._loadError=function(b){a._ajaxDone();a.say("Error connecting to server: "+a._ajaxCall);null!=b&&b()};a._isDatabaseCall=function(b){return 0<=a.db._databasePrefixes.indexOf(b.substring(0,
 1))};a._getDirectDatabaseCall=function(b,f){if(f&&!a.featureDetection.supportsXhr2())return b;var c=2,e=b.substring(0,c),d=a.db._DirectDatabaseCalls[e]||a.db._DirectDatabaseCalls[e=b.substring(0,--c)];d&&(":"==e?(e=b.toLowerCase(),isNaN(parseInt(b.substring(1)))?0==e.indexOf(":smiles:")?(d+="?POST?smiles="+b.substring(8),b="smiles"):0==e.indexOf(":cid:")?b="cid/"+b.substring(5):(0==e.indexOf(":name:")?b=b.substring(5):0==e.indexOf(":cas:")&&(b=b.substring(4)),b="name/"+encodeURIComponent(b.substring(c))):
 b="cid/"+b.substring(1)):b=encodeURIComponent(b.substring(c)),0<=b.indexOf(".mmtf")?b="https://mmtf.rcsb.org/v1.0/full/"+b.replace(/\.mmtf/,""):0<=d.indexOf("FILENCI")?(b=b.replace(/\%2F/g,"/"),b=d.replace(/\%FILENCI/,b)):b=d.replace(/\%FILE/,b));return b};a._getRawDataFromServer=function(b,f,c,e,d,g){b="?call=getRawDataFromDatabase&database="+b+(0<=f.indexOf("?POST?")?"?POST?":"")+"&query="+encodeURIComponent(f)+(d?"&encoding=base64":"")+(g?"":"&script="+encodeURIComponent(a._getScriptForDatabase(b)));
-return a._contactServer(b,c,e)};a._checkFileName=function(b,f,c){a._isDatabaseCall(f)&&(c&&a._setQueryTerm(b,f),f=a._getDirectDatabaseCall(f,!0),a._isDatabaseCall(f)&&(f=a._getDirectDatabaseCall(f,!1),c&&(c[0]=!0)));return f};a._checkCache=function(b,f,c){if(b._cacheFiles&&a._fileCache&&!f.endsWith(".js")){if(b=a._fileCache[f])return System.out.println("using "+b.length+" bytes of cached data for "+f),c(b),null;c=function(b,f){c(a._fileCache[b]=f)}}return c};a.playAudio=function(b){a._playAudio(null,
-b)};a._playAudio=function(b,a){var c=a.get?function(b){return a.get(b)}:null,e=a.put?function(b,c){return a.put(b,c)}:null,d=c?c("audioFile"):a,g=c&&c("audioPlayer"),h=document.createElement("audio");e&&e("audioElement",h);var l=null;g&&(l=function(b){g.processUpdate(b)},g.myClip={open:function(){l("open")},start:function(){h.play();l("start")},loop:function(b){h.loop=0!=b},stop:function(){h.pause()},close:function(){l("close")},setMicrosecondPosition:function(b){h.currentTime=b/1E6}});h.controls=
+return a._contactServer(b,c,e)};a._checkFileName=function(b,f,c){a._isDatabaseCall(f)&&(c&&a._setQueryTerm(b,f),f=a._getDirectDatabaseCall(f,!0),a._isDatabaseCall(f)&&(f=a._getDirectDatabaseCall(f,!1),c&&(c[0]=!0)));return f};a._checkCache=function(b,f,c){if(b._cacheFiles&&a._fileCache&&!f.endsWith(".js")){if(b=a._fileCache[f])return System.out.println("using "+b.length+" bytes of cached data for "+f),c(b),null;c=function(b,f){c(a._fileCache[b]=f)}}return c};a.playAudio=function(b){a.playAudio(null,
+b)};a.playAudio=function(b,a){var c=a.get?function(b){return a.get(b)}:null,e=a.put?function(b,c){return a.put(b,c)}:null,d=c?c("audioFile"):a,g=c&&c("audioPlayer"),h=document.createElement("audio");e&&e("audioElement",h);var l=null;g&&(l=function(b){g.processUpdate(b)},g.myClip={open:function(){l("open")},start:function(){h.play();l("start")},loop:function(b){h.loop=0!=b},stop:function(){h.pause()},close:function(){l("close")},setMicrosecondPosition:function(b){h.currentTime=b/1E6}});h.controls=
 "true";h.src=d;c&&c("loop")&&(h.loop="true");l&&(h.addEventListener("pause",function(){l("pause")}),h.addEventListener("play",function(){l("play")}),h.addEventListener("playing",function(){l("playing")}),h.addEventListener("ended",function(){l("ended")}),l("open"))};a._loadFileData=function(b,f,c,e){var d=[];f=a._checkFileName(b,f,d);c=a._checkCache(b,f,c);d[0]?a._getRawDataFromServer("_",f,c,e):(b={type:"GET",dataType:"text",url:f,async:a._asynchronous,success:function(b){a._loadSuccess(b,c)},error:function(){a._loadError(e)}},
 a._checkAjaxPost(b),a._ajax(b))};a._getInfoFromDatabase=function(b,f,c){if("===="==f){var e=a.db._restQueryXml.replace(/QUERY/,c),e={dataType:"text",type:"POST",contentType:"application/x-www-form-urlencoded",url:a.db._restQueryUrl,data:encodeURIComponent(e)+"&req=browser",success:function(e){a._ajaxDone();a._extractInfoFromRCSB(b,f,c,e)},error:function(){a._loadError(null)},async:a._asynchronous};return a._ajax(e)}c="?call=getInfoFromDatabase&database="+f+"&query="+encodeURIComponent(c);return a._contactServer(c,
 function(c){a._setInfo(b,f,c)})};a._extractInfoFromRCSB=function(b,f,c,e){var d=e.length/5;if(0!=d&&4==c.length&&1!=d){c=c.toUpperCase();var g=e.indexOf(c);0<g&&0<="123456789".indexOf(c.substring(0,1))&&(e=c+","+e.substring(0,g)+e.substring(g+5));50<d&&(e=e.substring(0,250));e=e.replace(/\n/g,",");e=a._restReportUrl.replace(/IDLIST/,e);a._loadFileData(b,e,function(c){a._setInfo(b,f,c)})}};a._checkAjaxPost=function(b){var a=b.url.indexOf("?POST?");0<a&&(b.data=b.url.substring(a+6),b.url=b.url.substring(0,
@@ -35,17 +35,17 @@ a),b.type="POST",b.contentType="application/x-www-form-urlencoded")};a._contactS
 a._getElement(b,"select");if(e&&e.options)for(var d=0;d<e.options.length;d++)e[d].value==c&&(e[d].selected=!0)}a.$val(a.$(b,"query"),f)}};a._search=function(b,f,c){1<arguments.length||(f=null);a._setQueryTerm(b,f);f||(f=a.$val(a.$(b,"query")));0==f.indexOf("!")?b._script(f.substring(1)):(f&&(f=f.replace(/\"/g,"")),b._showInfo(!1),a._searchMol(b,f,c,!0))};a._searchMol=function(b,f,c,e){var d;a._isDatabaseCall(f)?(d=f.substring(0,1),f=f.substring(1)):d=b._hasOptions?a.$val(a.$(b,"select")):"$";"="==
 d&&3==f.length&&(f="="+f);var g=d+f;if(f&&!(0>g.indexOf("?")&&g==b._thisJmolModel)){b._thisJmolModel=g;var h;e&&null!=b._viewSet&&null!=(h=a.View.__findView(b._viewSet,{chemID:g}))?a.View.__setView(h,b,!1):("$"==d||":"==d?b._jmolFileType="MOL":"="==d&&(b._jmolFileType="PDB"),b._searchDatabase(f,d,c))}};a._searchDatabase=function(b,f,c,e){b._showInfo(!1);return 0<=f.indexOf("?")?(a._getInfoFromDatabase(b,c,f.split("?")[0]),!0):a.db._DirectDatabaseCalls[c]?(b._loadFile(c+f,e),!0):!1};a._syncBinaryOK=
 "?";a._canSyncBinary=function(b){if(a._isAsync)return!0;if(self.VBArray)return a._syncBinaryOK=!1;if("?"!=a._syncBinaryOK)return a._syncBinaryOK;a._syncBinaryOK=!0;try{var f=new window.XMLHttpRequest;f.open("text",a._ajaxTestSite,!1);f.hasOwnProperty("responseType")?f.responseType="arraybuffer":f.overrideMimeType&&f.overrideMimeType("text/plain; charset=x-user-defined")}catch(c){return System.out.println("JSmolCore.js: synchronous binary file transfer is requested but not available"),a._alertNoBinary&&
-!b&&alert("JSmolCore.js: synchronous binary file transfer is requested but not available"),a._syncBinaryOK=!1}return!0};a._binaryTypes="mmtf .gz .bz2 .jpg .gif .png .zip .jmol .bin .smol .spartan .pmb .mrc .map .ccp4 .dn6 .delphi .omap .pse .dcd .uk/pdbe/densities/".split(" ");a._isBinaryUrl=function(b){for(var f=a._binaryTypes.length;0<=--f;)if(0<=b.indexOf(a._binaryTypes[f]))return!0;return!1};a._getFileData=function(b,f,c){var e=a._isBinaryUrl(b),d=0<=b.indexOf(".gz")&&0<=b.indexOf("rcsb.org");
-d&&(b=b.replace(/\.gz/,""),e=!1);var d=e&&!f&&!a._canSyncBinary(d),g=0<=b.indexOf("?POST?");0==b.indexOf("file:/")&&0!=b.indexOf("file:///")&&(b="file://"+b.substring(5));var h=0>b.indexOf("://")||0==b.indexOf(document.location.protocol)&&0<=b.indexOf(document.location.host),l="https://"==a._httpProto&&0==b.indexOf("http://"),j=a._isDirectCall(b);!j&&0<=b.indexOf("?ALLOWSORIGIN?")&&(j=!0,b=b.replace(/\?ALLOWSORIGIN\?/,""));var k=!h&&a.$supportsIECrossDomainScripting(),m=null;if(l||d||!h&&!j||!f&&
-k)m=a._getRawDataFromServer("_",b,f,f,d,!0);else{b=b.replace(/file:\/\/\/\//,"file://");var n={dataType:e?"binary":"text",async:!!f};g?(n.type="POST",n.url=b.split("?POST?")[0],n.data=b.split("?POST?")[1]):(n.type="GET",n.url=b);f&&(n.success=function(){f(a._xhrReturn(n.xhr))},n.error=function(){f(n.xhr.statusText)});n.xhr=a.$ajax(n);f||(m=a._xhrReturn(n.xhr))}if(!c)return m;null==m&&(m="",e=!1);e&&(e=a._canSyncBinary(!0));return e?a._strToBytes(m):JU.SB.newS(m)};a._xhrReturn=function(b){return!b.responseText||
+!b&&alert("JSmolCore.js: synchronous binary file transfer is requested but not available"),a._syncBinaryOK=!1}return!0};a._binaryTypes="mmtf .gz .bz2 .jpg .gif .png .zip .jmol .bin .smol .spartan .pmb .mrc .map .ccp4 .dn6 .delphi .omap .pse .dcd .uk/pdbe/densities/".split(" ");a.isBinaryUrl=function(b){for(var f=a._binaryTypes.length;0<=--f;)if(0<=b.indexOf(a._binaryTypes[f]))return!0;return!1};a._getFileData=function(b,f,c){var e=a.isBinaryUrl(b),d=0<=b.indexOf(".gz")&&0<=b.indexOf("rcsb.org");d&&
+(b=b.replace(/\.gz/,""),e=!1);var d=e&&!f&&!a._canSyncBinary(d),g=0<=b.indexOf("?POST?");0==b.indexOf("file:/")&&0!=b.indexOf("file:///")&&(b="file://"+b.substring(5));var h=0>b.indexOf("://")||0==b.indexOf(document.location.protocol)&&0<=b.indexOf(document.location.host),l="https://"==a._httpProto&&0==b.indexOf("http://"),j=a._isDirectCall(b);!j&&0<=b.indexOf("?ALLOWSORIGIN?")&&(j=!0,b=b.replace(/\?ALLOWSORIGIN\?/,""));var k=!h&&a.$supportsIECrossDomainScripting(),m=null;if(l||d||!h&&!j||!f&&k)m=
+a._getRawDataFromServer("_",b,f,f,d,!0);else{b=b.replace(/file:\/\/\/\//,"file://");var n={dataType:e?"binary":"text",async:!!f};g?(n.type="POST",n.url=b.split("?POST?")[0],n.data=b.split("?POST?")[1]):(n.type="GET",n.url=b);f&&(n.success=function(){f(a._xhrReturn(n.xhr))},n.error=function(){f(n.xhr.statusText)});n.xhr=a.$ajax(n);f||(m=a._xhrReturn(n.xhr))}if(!c)return m;null==m&&(m="",e=!1);e&&(e=a._canSyncBinary(!0));return e?a._strToBytes(m):JU.SB.newS(m)};a._xhrReturn=function(b){return!b.responseText||
 self.Clazz&&Clazz.instanceOf(b.response,self.ArrayBuffer)?b.response||b.statusText:b.responseText};a._isDirectCall=function(b){if(0<=b.indexOf("?ALLOWSORIGIN?"))return!0;for(var f in a.db._DirectDatabaseCalls)if(0<=f.indexOf(".")&&0<=b.indexOf(f))return!0;return!1};a._cleanFileData=function(b){return 0<=b.indexOf("\r")&&0<=b.indexOf("\n")?b.replace(/\r\n/g,"\n"):0<=b.indexOf("\r")?b.replace(/\r/g,"\n"):b};a._getFileType=function(b){var a=b.substring(0,1);if("$"==a||":"==a)return"MOL";if("="==a)return"="==
-b.substring(1,2)?"LCIF":"PDB";b=b.split(".").pop().toUpperCase();return b.substring(0,Math.min(b.length,3))};a._getZ=function(b,f){return b&&b._z&&b._z[f]||a._z[f]};a._incrZ=function(b,f){return b&&b._z&&++b._z[f]||++a._z[f]};a._hideLocalFileReader=function(b){b._localReader&&a.$setVisible(b._localReader,!1);b._readingLocal=!1;a._setCursor(b,0)};a.loadFileFromDialog=function(b){a._loadFileAsynchronously(null,b,null,null)};a._loadFileAsynchronously=function(b,f,c,e){if(c&&0!=c.indexOf("?")){var d=
-c;c=a._checkFileName(f,c);var g=function(g){a._setData(b,c,d,g,e,f)},g=a._checkCache(f,c,g);0<=c.indexOf("|")&&(c=c.split("|")[0]);return null==g?null:a._getFileData(c,g)}if(!a.featureDetection.hasFileReader)return b?b.setData("Local file reading is not enabled in your browser",null,null,e,f):alert("Local file reading is not enabled in your browser");f._localReader||(g='<div id="ID" style="z-index:'+a._getZ(f,"fileOpener")+';position:absolute;background:#E0E0E0;left:10px;top:10px"><div style="margin:5px 5px 5px 5px;"><button id="ID_loadurl">URL</button><input type="file" id="ID_files" /><button id="ID_loadfile">load</button><button id="ID_cancel">cancel</button></div><div>',
+b.substring(1,2)?"LCIF":"PDB";b=b.split(".").pop().toUpperCase();return b.substring(0,Math.min(b.length,3))};a._getZ=function(b,f){return b&&b._z&&b._z[f]||a._z[f]};a._incrZ=function(b,f){return b&&b._z&&++b._z[f]||++a._z[f]};a._hideLocalFileReader=function(b){b._localReader&&a.$setVisible(b._localReader,!1);b._readingLocal=!1;a.setCursor(b,0)};a.loadFileFromDialog=function(b){a.loadFileAsynchronously(null,b,null,null)};a.loadFileAsynchronously=function(b,f,c,e){if(c&&0!=c.indexOf("?")){var d=c;c=
+a._checkFileName(f,c);var g=function(g){a._setData(b,c,d,g,e,f)},g=a._checkCache(f,c,g);0<=c.indexOf("|")&&(c=c.split("|")[0]);return null==g?null:a._getFileData(c,g)}if(!a.featureDetection.hasFileReader)return b?b.setData("Local file reading is not enabled in your browser",null,null,e,f):alert("Local file reading is not enabled in your browser");f._localReader||(g='<div id="ID" style="z-index:'+a._getZ(f,"fileOpener")+';position:absolute;background:#E0E0E0;left:10px;top:10px"><div style="margin:5px 5px 5px 5px;"><button id="ID_loadurl">URL</button><input type="file" id="ID_files" /><button id="ID_loadfile">load</button><button id="ID_cancel">cancel</button></div><div>',
 a.$after("#"+f._id+"_appletdiv",g.replace(/ID/g,f._id+"_localReader")),f._localReader=a.$(f,"localReader"));a.$appEvent(f,"localReader_loadurl","click");a.$appEvent(f,"localReader_loadurl","click",function(){var b=prompt("Enter a URL");b&&(a._hideLocalFileReader(f,0),a._setData(null,b,b,null,e,f))});a.$appEvent(f,"localReader_loadfile","click");a.$appEvent(f,"localReader_loadfile","click",function(){var c=a.$(f,"localReader_files")[0].files[0],d=new FileReader;d.onloadend=function(d){d.target.readyState==
 FileReader.DONE&&(a._hideLocalFileReader(f,0),a._setData(b,c.name,c.name,d.target.result,e,f))};try{d.readAsArrayBuffer(c)}catch(g){alert("You must select a file first.")}});a.$appEvent(f,"localReader_cancel","click");a.$appEvent(f,"localReader_cancel","click",function(){a._hideLocalFileReader(f);b&&b.setData("#CANCELED#",null,null,e,f)});a.$setVisible(f._localReader,!0);f._readingLocal=!0};a._setData=function(b,f,c,e,d,g){e&&(e=a._strToBytes(e));null!=e&&(null==b||0<=f.indexOf(".jdx"))&&a.Cache.put("cache://"+
-f,e);null==b?g._applet.openFileAsyncSpecial(null==e?f:"cache://"+f,1):b.setData(f,c,e,d)};a._doAjax=function(b,f,c){b=b.toString();if(c){if(0!=b.indexOf("http://")&&0!=b.indexOf("https://"))return a._saveFile(b,c);b={async:!1,url:b,type:"POST",data:"string"==typeof data?c:";base64,"+(JU||J.util).Base64.getBase64(c).toString(),processData:!1};return a.$ajax(b).responseText}f&&(b+="?POST?"+f);return a._getFileData(b,null,!0)};a._saveFile=function(b,f,c,e){if(a._localFileSaveFunction&&a._localFileSaveFunction(b,
-f))return"OK";b=b.substring(b.lastIndexOf("/")+1);c||(c=0<=b.indexOf(".pdf")?"application/pdf":0<=b.indexOf(".png")?"image/png":0<=b.indexOf(".gif")?"image/gif":0<=b.indexOf(".jpg")?"image/jpg":"");f=(JU||J.util).Base64.getBase64("string"==typeof f?f.getBytes("UTF-8"):f).toString();e||(e="base64");var d=a._serverUrl;d&&0<=d.indexOf("your.server")&&(d="");a._useDataURI||!d?(e=document.createElement("a"),e.href="data:"+c+";base64,"+f,e.type=c||"text/plain;charset=utf-8",e.download=b,e.target="_blank",
-h("body").append(e),e.click(),e.remove()):(a._formdiv||(a.$after("body",'<div id="__jsmolformdiv__" style="display:none">\t\t\t\t\t\t<form id="__jsmolform__" method="post" target="_blank" action="">\t\t\t\t\t\t<input name="call" value="saveFile"/>\t\t\t\t\t\t<input id="__jsmolmimetype__" name="mimetype" value=""/>\t\t\t\t\t\t<input id="__jsmolencoding__" name="encoding" value=""/>\t\t\t\t\t\t<input id="__jsmolfilename__" name="filename" value=""/>\t\t\t\t\t\t<textarea id="__jsmoldata__" name="data"></textarea>\t\t\t\t\t\t</form>\t\t\t\t\t\t</div>'),
+f,e);null==b?g._applet.openFileAsyncSpecial(null==e?f:"cache://"+f,1):b.setData(f,c,e,d)};a.doAjax=function(b,f,c){b=b.toString();if(c){if(0!=b.indexOf("http://")&&0!=b.indexOf("https://"))return a._saveFile(b,c);b={async:!1,url:b,type:"POST",data:"string"==typeof data?c:";base64,"+(JU||J.util).Base64.getBase64(c).toString(),processData:!1};return a.$ajax(b).responseText}f&&(b+="?POST?"+f);return a._getFileData(b,null,!0)};a._saveFile=function(b,f,c,e){if(a._localFileSaveFunction&&a._localFileSaveFunction(b,
+f))return"OK";b=b.substring(b.lastIndexOf("/")+1);c||(c=0<=b.indexOf(".pdf")?"application/pdf":0<=b.indexOf(".png")?"image/png":0<=b.indexOf(".gif")?"image/gif":0<=b.indexOf(".jpg")?"image/jpg":"");var d="string"==typeof f;f=d&&0<=f.indexOf(";base64,")?f.split(";base64,")[1]:(JU||J.util).Base64.getBase64(d?f.getBytes("UTF-8"):f).toString();e||(e="base64");(d=a._serverUrl)&&0<=d.indexOf("your.server")&&(d="");a._useDataURI||!d?(e=document.createElement("a"),e.href="data:"+c+";base64,"+f,e.type=c||
+"text/plain;charset=utf-8",e.download=b,e.target="_blank",h("body").append(e),e.click(),e.remove()):(a._formdiv||(a.$after("body",'<div id="__jsmolformdiv__" style="display:none">\t\t\t\t\t\t<form id="__jsmolform__" method="post" target="_blank" action="">\t\t\t\t\t\t<input name="call" value="saveFile"/>\t\t\t\t\t\t<input id="__jsmolmimetype__" name="mimetype" value=""/>\t\t\t\t\t\t<input id="__jsmolencoding__" name="encoding" value=""/>\t\t\t\t\t\t<input id="__jsmolfilename__" name="filename" value=""/>\t\t\t\t\t\t<textarea id="__jsmoldata__" name="data"></textarea>\t\t\t\t\t\t</form>\t\t\t\t\t\t</div>'),
 a._formdiv="__jsmolform__"),a.$attr(a._formdiv,"action",d+"?"+(new Date).getMilliseconds()),a.$val("__jsmoldata__",f),a.$val("__jsmolfilename__",b),a.$val("__jsmolmimetype__",c),a.$val("__jsmolencoding__",e),a.$submit("__jsmolform__"),a.$val("__jsmoldata__",""),a.$val("__jsmolfilename__",""));return"OK"};a._strToBytes=function(b){if(Clazz.instanceOf(b,self.ArrayBuffer))return Clazz.newByteArray(-1,b);for(var a=Clazz.newByteArray(b.length,0),c=b.length;0<=--c;)a[c]=b.charCodeAt(c)&255;return a};a._setConsoleDiv=
 function(b){self.Clazz&&Clazz.setConsoleDiv(b)};a._registerApplet=function(b,f){return window[b]=a._applets[b]=a._applets[b+"__"+a._syncId+"__"]=f};a._readyCallback=function(b,f,c,e,d){b=b.split("_object")[0];var g=a._applets[b];if(c=c.booleanValue?c.booleanValue():c)g._appletPanel=d||e,g._applet=e;a._track(g)._readyCallback(b,f,c)};a._getWrapper=function(b,f){var c;if(f){var e="";if(b._coverImage)var e=' onclick="Jmol.coverApplet(ID, false)" title="'+b._coverTitle+'"',d='<image id="ID_coverclickgo" src="'+
 b._makeLiveImage+'" style="width:25px;height:25px;position:absolute;bottom:10px;left:10px;z-index:'+a._getZ(b,"coverImage")+';opacity:0.5;"'+e+" />",e='<div id="ID_coverdiv" style="background-color:red;z-index:'+a._getZ(b,"coverImage")+';width:100%;height:100%;display:inline;position:absolute;top:0px;left:0px"><image id="ID_coverimage" src="'+b._coverImage+'" style="width:100%;height:100%"'+e+"/>"+d+"</div>";d=b._isJava?"":'<image id="ID_waitimage" src="'+b._j2sPath+'/img/cursor_wait.gif" style="display:none;position:absolute;bottom:10px;left:10px;z-index:'+
@@ -61,7 +61,7 @@ a._destroy=function(b){try{b._appletPanel&&b._appletPanel.destroy();b._applet=nu
 function(b,f){app=a._applets[b];if(app._viewSet)a.View.updateFromSync(app,f);else{if(!a._syncReady||!a._isJmolJSVSync)return 1;for(var c=0;c<a._syncedApplets.length;c++)0<=f.indexOf(a._syncedApplets[c]._syncKeyword)&&a._syncedApplets[c]._syncScript(f);return 0}};a._getElement=function(b,a){return document.getElementById(b._id+"_"+a)||{}};a._evalJSON=function(b,a){b+="";if(!b)return[];if("{"!=b.charAt(0))return 0<=b.indexOf(" | ")&&(b=b.replace(/\ \|\ /g,"\n")),b;var c=(new Function("return "+b))();
 return!c?null:a&&void 0!=c[a]?c[a]:c};a._sortMessages=function(b){function a(b,c){return b[0]<c[0]?1:b[0]>c[0]?-1:0}if(!b||"object"!=typeof b)return[];for(var c=[],e=b.length-1;0<=e;e--)for(var d=0,g=b[e].length;d<g;d++)c[c.length]=b[e][d];if(0!=c.length)return c=c.sort(a)};a._setMouseOwner=function(b,f){null==b||f?a._mouseOwner=b:a._mouseOwner==b&&(a._mouseOwner=null)};a._jsGetMouseModifiers=function(b){var a=0;switch(b.button){case 0:a=16;break;case 1:a=8;break;case 2:a=4}b.shiftKey&&(a+=1);b.altKey&&
 (a+=8);b.ctrlKey&&(a+=2);return a};a._jsGetXY=function(b,f){if(!b.applet._ready||a._touching&&0>f.type.indexOf("touch"))return!1;var c=a.$offset(b.id),e,d=f.originalEvent;f.pageX||(f.pageX=d.pageX);f.pageY||(f.pageY=d.pageY);a._mousePageX=f.pageX;a._mousePageY=f.pageY;d.targetTouches&&d.targetTouches[0]?(e=d.targetTouches[0].pageX-c.left,c=d.targetTouches[0].pageY-c.top):d.changedTouches?(e=d.changedTouches[0].pageX-c.left,c=d.changedTouches[0].pageY-c.top):(e=f.pageX-c.left,c=f.pageY-c.top);return void 0==
-e?null:[Math.round(e),Math.round(c),a._jsGetMouseModifiers(f)]};a._setCursor=function(b,f){if(!b._isJava&&!b._readingLocal){var c;switch(f){case 1:c="crosshair";break;case 3:c="wait";a.$setVisible(a.$(b,"waitimage"),!0);break;case 8:c="ns-resize";break;case 12:c="grab";break;case 13:c="move";break;default:a.$setVisible(a.$(b,"waitimage"),!1),c="default"}b._canvas.style.cursor=c}};a._gestureUpdate=function(b,f){f.stopPropagation();f.preventDefault();var c=f.originalEvent;switch(f.type){case "touchstart":a._touching=
+e?null:[Math.round(e),Math.round(c),a._jsGetMouseModifiers(f)]};a.setCursor=function(b,f){if(!b._isJava&&!b._readingLocal){var c;switch(f){case 1:c="crosshair";break;case 3:c="wait";a.$setVisible(a.$(b,"waitimage"),!0);break;case 8:c="ns-resize";break;case 12:c="grab";break;case 13:c="move";break;default:a.$setVisible(a.$(b,"waitimage"),!1),c="default"}b._canvas.style.cursor=c}};a._gestureUpdate=function(b,f){f.stopPropagation();f.preventDefault();var c=f.originalEvent;switch(f.type){case "touchstart":a._touching=
 !0;break;case "touchend":a._touching=!1}if(!c.touches||2!=c.touches.length)return!1;switch(f.type){case "touchstart":b._touches=[[],[]];break;case "touchmove":var e=a.$offset(b.id),d=b._touches[0],g=b._touches[1];d.push([c.touches[0].pageX-e.left,c.touches[0].pageY-e.top]);g.push([c.touches[1].pageX-e.left,c.touches[1].pageY-e.top]);c=d.length;3<c&&(d.shift(),g.shift());2<=c&&b.applet._processGesture(b._touches)}return!0};a._jsSetMouse=function(b){var f=function(b){return!b.target||0<=(""+b.target.className).indexOf("swingjs-ui")};
 a.$bind(b,"mousedown touchstart",function(c){if(f(c))return!0;a._setMouseOwner(b,!0);c.stopPropagation();var e=c.target["data-UI"];(!e||!e.handleJSEvent(b,501,c))&&c.preventDefault();b.isDragging=!0;if("touchstart"==c.type&&a._gestureUpdate(b,c))return!!e;a._setConsoleDiv(b.applet._console);var d=a._jsGetXY(b,c);d&&(2!=c.button&&a.Swing.hideMenus(b.applet),b.applet._processEvent(501,d));return!!e});a.$bind(b,"mouseup touchend",function(c){if(f(c))return!0;a._setMouseOwner(null);c.stopPropagation();
 var e=c.target["data-UI"];(!e||!e.handleJSEvent(b,502,c))&&c.preventDefault();b.isDragging=!1;if("touchend"==c.type&&a._gestureUpdate(b,c))return!!e;(c=a._jsGetXY(b,c))&&b.applet._processEvent(502,c);return!!e});a.$bind(b,"mousemove touchmove",function(c){if(f(c))return!0;if(a._mouseOwner&&a._mouseOwner!=b&&a._mouseOwner.isDragging){if(!a._mouseOwner.mouseMove)return!0;a._mouseOwner.mouseMove(c);return!1}return a._drag(b,c)});a._drag=function(b,e){e.stopPropagation();e.preventDefault();if("touchmove"==
