@@ -133,7 +133,9 @@ if (this.isMolecular) return (this.doGetModel (++this.modelNumber, null) ? this.
 this.readCoordLines ();
 this.checkModelTrigger = true;
 }if (this.isProperties && this.line.startsWith ("   ATOM N.AT.")) {
-if (this.doGetModel (++this.modelNumber, null) ? this.readAtoms () : this.checkLastModel ()) ;}if (!this.doProcessLines) return true;
+if (this.doGetModel (++this.modelNumber, null)) this.readAtoms ();
+ else this.checkLastModel ();
+}if (!this.doProcessLines) return true;
 if (this.line.startsWith (" TOTAL ENERGY(")) {
 this.line = JU.PT.rep (this.line, "( ", "(");
 var tokens = this.getTokens ();
@@ -324,9 +326,14 @@ this.discardLinesUntilContains ("***********************************************
 this.readLines (2);
 this.isVersion3 = (this.line.indexOf ("CRYSTAL03") >= 0);
 this.discardLinesUntilContains ("EEEEEEEEEE");
+this.rd ();
 var name;
-if (this.rd ().length == 0) {
-name = this.readLines (2).trim ();
+while (this.line.startsWith (" INFORMATION") || this.line.startsWith (" WARNING")) {
+this.rd ();
+}
+if (this.line.length == 0) {
+this.discardLinesUntilContains ("*********");
+name = this.rd ().trim ();
 } else {
 name = this.line.trim ();
 this.rd ();
