@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.adapter.smarter");
-Clazz.load (["javajs.api.GenericLineReader", "JU.SB"], "J.adapter.smarter.AtomSetCollectionReader", ["java.io.BufferedReader", "java.lang.Boolean", "$.Float", "$.NullPointerException", "javajs.api.GenericBinaryDocument", "JU.BS", "$.Lst", "$.M3", "$.P3", "$.PT", "$.Quat", "$.T4", "$.V3", "J.adapter.smarter.Atom", "$.AtomSetCollection", "J.api.Interface", "$.JmolAdapter", "JU.BSUtil", "$.Logger"], function () {
+Clazz.load (["javajs.api.GenericLineReader", "JU.SB"], "J.adapter.smarter.AtomSetCollectionReader", ["java.io.BufferedReader", "java.lang.Boolean", "$.Double", "$.Float", "$.NullPointerException", "javajs.api.GenericBinaryDocument", "JU.BS", "$.Lst", "$.M3", "$.P3", "$.PT", "$.Quat", "$.T4", "$.V3", "J.adapter.smarter.Atom", "$.AtomSetCollection", "J.api.Interface", "$.JmolAdapter", "JU.BSUtil", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.isBinary = false;
 this.debugging = false;
@@ -810,6 +810,21 @@ data[i] = JU.PT.getTokens (this.discardLinesUntilNonBlank ());
 if (data[i].length < minLineLen) --i;
 }
 }, "~A,~N");
+Clazz.defineMethod (c$, "fill3x3", 
+function (tokens, pt) {
+var a =  Clazz.newDoubleArray (3, 3, 0);
+var needTokens = (tokens == null);
+var pt0 = pt;
+for (var i = 0; i < 3; i++) {
+if (needTokens || pt >= tokens.length) {
+while ((tokens = JU.PT.getTokens (this.rd ())).length < 3) {
+}
+pt = (pt0 < 0 ? tokens.length + pt0 : pt0);
+}for (var j = 0; j < 3; j++) a[i][j] = Double.$valueOf (tokens[pt++]).doubleValue ();
+
+}
+return a;
+}, "~A,~N");
 Clazz.defineMethod (c$, "fillFloatArray", 
 function (s, width, data) {
 var tokens =  new Array (0);
@@ -833,7 +848,7 @@ return data;
 }, "~S,~N,~A");
 Clazz.defineMethod (c$, "fillFrequencyData", 
 function (iAtom0, ac, modelAtomCount, ignore, isWide, col0, colWidth, atomIndexes, minLineLen, data) {
-var withSymmetry = (modelAtomCount != ac && data == null);
+var withSymmetry = (ac != 0 && modelAtomCount != ac && data == null);
 if (ac == 0 && atomIndexes != null) ac = atomIndexes.length;
 var nLines = (isWide ? ac : ac * 3);
 var nFreq = ignore.length;
