@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JM");
-Clazz.load (null, "JM.Minimizer", ["java.lang.Float", "java.util.Hashtable", "JU.AU", "$.BS", "$.Lst", "J.i18n.GT", "JM.MinAngle", "$.MinAtom", "$.MinBond", "$.MinTorsion", "$.MinimizationThread", "JM.FF.ForceFieldMMFF", "$.ForceFieldUFF", "JU.BSUtil", "$.Escape", "$.Logger"], function () {
+Clazz.load (null, "JM.Minimizer", ["java.lang.Float", "java.util.Hashtable", "JU.AU", "$.BS", "$.Lst", "J.i18n.GT", "JM.MMConstraint", "$.MinAngle", "$.MinAtom", "$.MinBond", "$.MinTorsion", "$.MinimizationThread", "JM.FF.ForceFieldMMFF", "$.ForceFieldUFF", "JU.BSUtil", "$.Escape", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.vwr = null;
 this.atoms = null;
@@ -75,23 +75,26 @@ return (this.pFF == null ? "" : this.pFF.getLogData ());
 }return null;
 }, "~S,~N");
 Clazz.defineMethod (c$, "addConstraint", 
- function (c) {
-if (c == null) return;
-var atoms = c[0];
-var nAtoms = atoms[0];
+ function (o) {
+if (o == null) return;
+var indexes = o[0];
+var nAtoms = indexes[0];
 if (nAtoms == 0) {
 this.constraints = null;
 return;
-}if (this.constraints == null) {
+}var value = (o[1]).doubleValue ();
+if (this.constraints == null) {
 this.constraints =  new JU.Lst ();
 this.constraintMap =  new java.util.Hashtable ();
-}if (atoms[1] > atoms[nAtoms]) {
-JU.AU.swapInt (atoms, 1, nAtoms);
-if (nAtoms == 4) JU.AU.swapInt (atoms, 2, 3);
-}var id = JU.Escape.eAI (atoms);
-var c1 = this.constraintMap.get (id);
-if (c1 != null) {
-c1[2] = c[2];
+}if (indexes[1] > indexes[nAtoms]) {
+JU.AU.swapInt (indexes, 1, nAtoms);
+if (nAtoms == 4) JU.AU.swapInt (indexes, 2, 3);
+}var id = JU.Escape.eAI (indexes);
+var c = this.constraintMap.get (id);
+if (c == null) {
+c =  new JM.MMConstraint (indexes, value);
+} else {
+c.value = value;
 return;
 }this.constraintMap.put (id, c);
 this.constraints.addLast (c);
@@ -167,8 +170,8 @@ this.setAtomPositions ();
 if (this.constraints != null) {
 for (var i = this.constraints.size (); --i >= 0; ) {
 var constraint = this.constraints.get (i);
-var aList = constraint[0];
-var minList = constraint[1];
+var aList = constraint.indexes;
+var minList = constraint.minList;
 var nAtoms = aList[0] = Math.abs (aList[0]);
 for (var j = 1; j <= nAtoms; j++) {
 if (steps <= 0 || !this.bsAtoms.get (aList[j])) {
