@@ -81,6 +81,7 @@ return this.evaluateFormat (mp, op.intValue, args, tok == 1825200146);
 case 134320141:
 return this.evaluateUserFunction (mp, op.value, args, op.intValue, op.tok == 268435665);
 case 1275068449:
+case 1275068437:
 case 1275082245:
 case 1275072526:
 return this.evaluateGetProperty (mp, args, tok, op.tok == 268435665);
@@ -269,7 +270,7 @@ var toPrimitive = "primitive".equalsIgnoreCase (op);
 if (toPrimitive || "conventional".equalsIgnoreCase (op)) {
 var stype = (++ptParam > lastParam ? "" : args[ptParam].asString ().toUpperCase ());
 if (stype.equals ("BCC")) stype = "I";
- else if (stype.length == 0) stype = this.vwr.getSymTemp ().getSymmetryInfoAtom (this.vwr.ms, iatom, null, 0, null, null, null, 1073741994, 0, -1);
+ else if (stype.length == 0) stype = this.vwr.getSymmetryInfo (iatom, null, 0, null, null, 1073741994, null, 0, -1, 0);
 if (stype == null || stype.length == 0) return false;
 if (u == null) u = this.vwr.getSymTemp ();
 var m3 = this.vwr.getModelForAtomIndex (iatom).auxiliaryInfo.get ("primitiveToCrystal");
@@ -1051,19 +1052,21 @@ return mp.addXStr (this.vwr.getJBR ().toStdAmino3 (JS.SV.sValue (x1)));
 }, "JS.ScriptMathProcessor,~A");
 Clazz.defineMethod (c$, "evaluateGetProperty", 
  function (mp, args, tok0, isAtomProperty) {
+var nargs = args.length;
 var isSelect = (isAtomProperty && tok0 == 1275082245);
+var isPivot = (isAtomProperty && tok0 == 1275068437 && nargs > 0);
 var isAuxiliary = (tok0 == 1275068449);
 var pt = 0;
-var tok = (args.length == 0 ? 0 : args[0].tok);
-if (args.length == 2 && (tok == 7 || tok == 6 || tok == 14)) {
+var tok = (nargs == 0 ? 0 : args[0].tok);
+if (nargs == 2 && (tok == 7 || tok == 6 || tok == 14)) {
 return mp.addXObj (this.vwr.extractProperty (args[0].value, args[1].value.toString (), -1));
-}var bsSelect = (isAtomProperty && args.length == 1 && args[0].tok == 10 ? args[0].value : null);
-var pname = (bsSelect == null && args.length > 0 ? JS.SV.sValue (args[pt++]) : "");
+}var bsSelect = (isAtomProperty && nargs == 1 && args[0].tok == 10 ? args[0].value : null);
+var pname = (bsSelect == null && nargs > 0 ? JS.SV.sValue (args[pt++]) : "");
 var propertyName = pname;
 var lc = propertyName.toLowerCase ();
 if (!isSelect && lc.indexOf ("[select ") < 0) propertyName = lc;
 var isJSON = false;
-if (propertyName.equals ("json") && args.length > pt) {
+if (propertyName.equals ("json") && nargs > pt) {
 isJSON = true;
 propertyName = JS.SV.sValue (args[pt++]);
 }var x = null;
@@ -1093,7 +1096,29 @@ data[1] = Integer.$valueOf (-1);
 this.vwr.shm.getShapePropertyData (shapeID, pname.intern (), data);
 }}return (data[1] == null ? mp.addXStr ("") : mp.addXObj (data[1]));
 case 7:
-if (bsSelect != null) {
+if (isPivot) {
+var lstx = x.getList ();
+var map =  new java.util.Hashtable ();
+var sep = (nargs > 1 ? JS.SV.sValue (args[nargs - 1]) : null);
+if (sep != null) nargs--;
+var keys =  new Array (nargs);
+for (var i = 0; i < nargs; i++) keys[i] = JS.SV.sValue (args[i]);
+
+for (var i = 0, n = lstx.size (); i < n; i++) {
+var sv = lstx.get (i);
+if (sv.tok != 6) continue;
+var mapi = sv.getMap ();
+var key = "";
+for (var j = 0; j < nargs; j++) {
+var obj = mapi.get (keys[j]);
+key += (j == 0 ? "" : sep) + JS.SV.sValue (obj);
+}
+var vlist = map.get (key);
+if (vlist == null) map.put (key, vlist = JS.SV.newV (7,  new JU.Lst ()));
+vlist.getList ().addLast (sv);
+}
+return mp.addXMap (map);
+}if (bsSelect != null) {
 var l0 = x.getList ();
 var lst =  new JU.Lst ();
 for (var i = bsSelect.nextSetBit (0); i >= 0; i = bsSelect.nextSetBit (i + 1)) lst.addLast (l0.get (i));
@@ -1103,19 +1128,19 @@ return mp.addXList (lst);
 if (isSelect) propertyName = "[SELECT " + propertyName + "]";
 return mp.addXObj (this.vwr.extractProperty (x, propertyName, -1));
 }
-if (!lc.startsWith ("bondinfo") && !lc.startsWith ("atominfo")) propertyName = "atomInfo." + propertyName;
+if (!lc.startsWith ("bondinfo") && !lc.startsWith ("atominfo") && !lc.startsWith ("modelkitinfo")) propertyName = "atomInfo." + propertyName;
 }var propertyValue = "";
-if (propertyName.equalsIgnoreCase ("fileContents") && args.length >= 2) {
+if (propertyName.equalsIgnoreCase ("fileContents") && nargs >= 2) {
 var s = JS.SV.sValue (args[1]);
-for (var i = 2; i < args.length; i++) s += "|" + JS.SV.sValue (args[i]);
+for (var i = 2; i < nargs; i++) s += "|" + JS.SV.sValue (args[i]);
 
 propertyValue = s;
-pt = args.length;
-} else if (args.length > pt) {
+pt = nargs;
+} else if (nargs > pt) {
 switch (args[pt].tok) {
 case 10:
 propertyValue = args[pt++].value;
-if (propertyName.equalsIgnoreCase ("bondInfo") && args.length > pt && args[pt].tok == 10) propertyValue =  Clazz.newArray (-1, [propertyValue, args[pt].value]);
+if (propertyName.equalsIgnoreCase ("bondInfo") && nargs > pt && args[pt].tok == 10) propertyValue =  Clazz.newArray (-1, [propertyValue, args[pt].value]);
 break;
 case 6:
 case 4:
@@ -1130,7 +1155,7 @@ propertyValue = bs;
 }if (isAuxiliary && !isAtomProperty) propertyName = "auxiliaryInfo.models." + propertyName;
 propertyName = JU.PT.rep (propertyName, ".[", "[");
 var property = this.vwr.getProperty (null, propertyName, propertyValue);
-if (pt < args.length) property = this.vwr.extractProperty (property, args, pt);
+if (pt < nargs) property = this.vwr.extractProperty (property, args, pt);
 return mp.addXObj (isJSON ? JS.SV.safeJSON ("value", property) : JS.SV.isVariableType (property) ? property : JU.Escape.toReadable (propertyName, property));
 }, "JS.ScriptMathProcessor,~A,~N,~B");
 Clazz.defineMethod (c$, "evaluateFormat", 
@@ -2115,11 +2140,11 @@ if (apt + 1 < narg && args[apt + 1].tok == 10) (bsAtoms == null ? (bsAtoms =  ne
 var pt2 = null;
 if ((pt1 = (narg > apt ? mp.ptValue (args[apt], bsAtoms) : null)) != null) apt++;
 if ((pt2 = (narg > apt ? mp.ptValue (args[apt], bsAtoms) : null)) != null) apt++;
-var nth = (pt2 != null && args.length > apt && iOp == -2147483648 && args[apt].tok == 2 ? args[apt].intValue : 0);
-if (nth > 0) apt++;
+var nth = (pt2 != null && args.length > apt && iOp == -2147483648 && args[apt].tok == 2 ? args[apt].intValue : -1);
+if (nth >= 0) apt++;
 if (iOp == -2147483648) iOp = 0;
 var desc = (narg == apt ? (pt2 != null ? "all" : pt1 != null ? "point" : "matrix") : JS.SV.sValue (args[apt++]).toLowerCase ());
-return (bsAtoms != null && !bsAtoms.isEmpty () && apt == args.length && mp.addXObj (this.vwr.getSymTemp ().getSymmetryInfoAtom (this.vwr.ms, bsAtoms.nextSetBit (0), xyz, iOp, pt1, pt2, desc, 0, 0, nth)));
+return (bsAtoms != null && !bsAtoms.isEmpty () && apt == args.length && mp.addXObj (this.vwr.getSymmetryInfo (bsAtoms.nextSetBit (0), xyz, iOp, pt1, pt2, 0, desc, 0, nth, 0)));
 }, "JS.ScriptMathProcessor,~A,~B");
 Clazz.defineMethod (c$, "evaluateTensor", 
  function (mp, args) {
@@ -2403,7 +2428,7 @@ var ndata = 0;
 var htPivot = null;
 while (true) {
 if (JU.AU.isAF (floatOrSVArray)) {
-if (tok == 1140850707) return "NaN";
+if (tok == 1275068437) return "NaN";
 data = floatOrSVArray;
 ndata = data.length;
 if (ndata == 0) break;
@@ -2411,7 +2436,7 @@ if (ndata == 0) break;
 sv = floatOrSVArray;
 ndata = sv.size ();
 if (ndata == 0) {
-if (tok != 1140850707) break;
+if (tok != 1275068437) break;
 } else {
 var sv0 = sv.get (0);
 if (sv0.tok == 8) return this.getMinMaxPoint (sv, tok);
@@ -2426,7 +2451,7 @@ break;
 var minMax;
 var isMin = false;
 switch (tok) {
-case 1140850707:
+case 1275068437:
 htPivot =  new java.util.Hashtable ();
 sum = minMax = 0;
 break;
@@ -2445,7 +2470,7 @@ sum = minMax = 0;
 var sum2 = 0;
 var n = 0;
 var isInt = true;
-var isPivot = (tok == 1140850707);
+var isPivot = (tok == 1275068437);
 for (var i = ndata; --i >= 0; ) {
 var svi = (sv == null ? JS.SV.vF : sv.get (i));
 var v = (isPivot ? 1 : data == null ? JS.SV.fValue (svi) : data[i]);
@@ -2459,7 +2484,7 @@ case 128:
 case 96:
 sum += v;
 break;
-case 1140850707:
+case 1275068437:
 isInt = new Boolean (isInt & (svi.tok == 2)).valueOf ();
 var key = svi.asString ();
 var ii = htPivot.get (key);
@@ -2474,7 +2499,7 @@ if (isInt) minMax = svi.intValue;
 }break;
 }
 }
-if (tok == 1140850707) {
+if (tok == 1275068437) {
 return htPivot;
 }if (n == 0) break;
 switch (tok) {
