@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (null, "JS.SymmetryDesc", ["java.lang.Float", "java.util.Hashtable", "JU.BS", "$.M4", "$.Measure", "$.P3", "$.P4", "$.PT", "$.Quat", "$.SB", "$.V3", "JM.Atom", "JS.T", "JS.SpaceGroup", "$.Symmetry", "$.SymmetryOperation", "JU.Escape", "$.Logger"], function () {
+Clazz.load (null, "JS.SymmetryDesc", ["java.lang.Float", "java.util.Hashtable", "JU.BS", "$.Lst", "$.M4", "$.Measure", "$.P3", "$.P4", "$.PT", "$.Quat", "$.SB", "$.V3", "JM.Atom", "JS.T", "JS.SpaceGroup", "$.Symmetry", "$.SymmetryOperation", "JU.Escape", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.modelSet = null;
 Clazz.instantialize (this, arguments);
@@ -13,25 +13,26 @@ this.modelSet = modelSet;
 return this;
 }, "JM.ModelSet");
 Clazz.defineMethod (c$, "getSymopInfo", 
-function (iAtom, xyz, op, pt, pt2, id, type, scaleFactor, nth) {
+function (iAtom, xyz, op, pt, pt2, id, type, scaleFactor, nth, options) {
 if (type == 0) type = JS.SymmetryDesc.getType (id);
 var ret = (type == 1140850689 ?  new JU.BS () : "");
 if (iAtom < 0) return ret;
 var iModel = this.modelSet.at[iAtom].mi;
 var uc = this.modelSet.am[iModel].biosymmetry;
 if (uc == null && (uc = this.modelSet.getUnitCell (iModel)) == null) return ret;
-if (type != 135176 || op != 2147483647) return this.getSymmetryInfo (uc, iModel, iAtom, uc, xyz, op, pt, pt2, id, type, scaleFactor, nth);
-var s = "";
+if (type != 135176 || op != 2147483647) {
+return this.getSymmetryInfo (uc, iModel, iAtom, uc, xyz, op, pt, pt2, id, type, scaleFactor, nth, options);
+}var s = "";
 var ops = uc.getSymmetryOperations ();
 if (ops != null) {
 if (id == null) id = "sg";
 var n = ops.length;
-for (op = 0; op < n; op++) s += this.getSymmetryInfo (uc, iModel, iAtom, uc, xyz, op, pt, pt2, id + op, 135176, scaleFactor, nth);
+for (op = 0; op < n; op++) s += this.getSymmetryInfo (uc, iModel, iAtom, uc, xyz, op, pt, pt2, id + op, 135176, scaleFactor, nth, options);
 
 }return s;
-}, "~N,~S,~N,JU.P3,JU.P3,~S,~N,~N,~N");
+}, "~N,~S,~N,JU.P3,JU.P3,~S,~N,~N,~N,~N");
 Clazz.defineMethod (c$, "getSpaceGroupInfo", 
-function (sym, modelIndex, sgName, symOp, pt1, pt2, drawID, scaleFactor, nth, isFull, isForModel) {
+function (sym, modelIndex, sgName, symOp, pt1, pt2, drawID, scaleFactor, nth, isFull, isForModel, options) {
 var info = null;
 var cellInfo = null;
 var isStandard = (pt1 == null && drawID == null && nth <= 0);
@@ -73,7 +74,7 @@ op = sym.getSpaceGroupOperation (i);
 if (op == null) continue;
 if (op.timeReversal != 0 || op.modDim > 0) isStandard = false;
 if (slist != null) slist += ";" + op.xyz;
-var ret = (symOp > 0 && symOp - 1 != iop ? null : this.createInfoArray (op, cellInfo, pt1, pt2, drawID, scaleFactor));
+var ret = (symOp > 0 && symOp - 1 != iop ? null : this.createInfoArray (op, cellInfo, pt1, pt2, drawID, scaleFactor, options));
 if (ret != null) {
 if (nth > 0 && ++nop != nth) continue;
 infolist[i] = ret;
@@ -98,7 +99,7 @@ data = sym.getSpaceGroupInfoObj (sgName, cellInfo, isFull);
 if (data == null || data.equals ("?")) data = "could not identify space group from name: " + sgName + "\nformat: show spacegroup \"2\" or \"P 2c\" " + "or \"C m m m\" or \"x, y, z;-x ,-y, -z\"";
 }info.put ("spaceGroupInfo", data);
 return info;
-}, "JS.Symmetry,~N,~S,~N,JU.P3,JU.P3,~S,~N,~N,~B,~B");
+}, "JS.Symmetry,~N,~S,~N,JU.P3,JU.P3,~S,~N,~N,~B,~B,~N");
 c$.getType = Clazz.defineMethod (c$, "getType", 
  function (id) {
 var type;
@@ -114,53 +115,77 @@ for (type = 0; type < JS.SymmetryDesc.keys.length; type++) if (id.equalsIgnoreCa
 
 return 1073741961;
 }, "~S");
+c$.nullReturn = Clazz.defineMethod (c$, "nullReturn", 
+ function (type) {
+switch (type) {
+case 135176:
+return "draw ID sym_* delete";
+case 1073741961:
+case 1825200146:
+case 1145047050:
+case 1073742078:
+return "";
+case 1140850689:
+return  new JU.BS ();
+default:
+return null;
+}
+}, "~N");
 c$.getInfo = Clazz.defineMethod (c$, "getInfo", 
  function (info, type) {
-if (info == null) return "";
 if (type < 0 && type >= -JS.SymmetryDesc.keys.length) return info[-1 - type];
 switch (type) {
 case 1073742327:
+case 1073741982:
 return info;
 case 1275068418:
 var lst =  new java.util.Hashtable ();
-for (var j = 0, n = info.length; j < n; j++) if (JS.SymmetryDesc.keys[j] != null && info[j] != null) lst.put (JS.SymmetryDesc.keys[j], info[j]);
-
+for (var j = 0, n = info.length; j < n; j++) {
+var key = (j == 3 ? "draw" : j == 7 ? "axispoint" : JS.SymmetryDesc.keys[j]);
+if (info[j] != null) lst.put (key, info[j]);
+}
 return lst;
-case 134217729:
-return info[9];
-case 1073741854:
-return info[8];
-case 12289:
-return info[6];
-case 135176:
-return info[3] + "\nprint " + JU.PT.esc (info[0] + " " + info[2]);
 case 1073741961:
 return info[0] + "  \t" + info[2];
-case 1073741982:
-return info;
+case 1145047050:
+return info[0];
+case 1073742078:
+return info[1];
 default:
 case 1825200146:
 return info[2];
-case 12:
-return info[10];
+case 135176:
+return info[3] + "\nprint " + JU.PT.esc (info[0] + " " + info[2]);
+case 1145047051:
+return info[4];
+case 1073742178:
+return info[5];
+case 12289:
+return info[6];
 case 134217751:
 return info[7];
+case 1073741854:
+return info[8];
+case 134217729:
+return info[9];
+case 12:
+return info[10];
+case 1814695966:
+return info[11];
+case 4160:
+return info[12];
 case 268435633:
 return info[13];
 case 134217750:
 return info[14];
-case 1073742178:
-return info[5];
-case 1814695966:
-return info[11];
-case 1145047050:
-return info[0];
+case 1140850696:
+return info[15];
 case 1073741974:
 return info[16];
 }
 }, "~A,~N");
 Clazz.defineMethod (c$, "createInfoArray", 
- function (op, uc, pta00, ptTarget, id, scaleFactor) {
+ function (op, uc, pta00, ptTarget, id, scaleFactor, options) {
 if (!op.isFinalized) op.doFinalize ();
 var isTimeReversed = (op.timeReversal == -1);
 if (scaleFactor == 0) scaleFactor = 1;
@@ -446,7 +471,7 @@ opType = drawid + "inv";
 draw1.append (drawid).append ("invPoint diameter 0.4 ").append (JU.Escape.eP (ipt));
 ptemp.sub2 (ptinv, pta00);
 JS.SymmetryDesc.drawVector (draw1, drawid, "invArrow", "vector", pta00, ptemp, isTimeReversed ? "gray" : "cyan");
-if (!isInversionOnly) {
+if (!isInversionOnly && options != 1073742066) {
 JS.SymmetryDesc.drawFrameLine ("X", ptinv, vt1, 0.15, ptemp, draw1, opType, "red");
 JS.SymmetryDesc.drawFrameLine ("Y", ptinv, vt2, 0.15, ptemp, draw1, opType, "green");
 JS.SymmetryDesc.drawFrameLine ("Z", ptinv, vt3, 0.15, ptemp, draw1, opType, "blue");
@@ -468,10 +493,11 @@ draw1.append ("\nvar p0 = " + JU.Escape.eP (ptemp2));
 draw1.append ("\nvar set2 = within(0.2,p0);if(!set2){set2 = within(0.2,p0.uxyz.xyz)}");
 if (Clazz.instanceOf (pta00, JM.Atom)) draw1.append ("\n set2 &= {_" + (pta00).getElementSymbol () + "}");
 draw1.append ("\nsym_target = set2;if (set2) {");
+if (options != 1073742066 && ptTarget == null) {
 draw1.append (drawid).append ("offsetFrameX diameter 0.20 @{set2.xyz} @{set2.xyz + ").append (JU.Escape.eP (vt1)).append ("*0.9} color red");
 draw1.append (drawid).append ("offsetFrameY diameter 0.20 @{set2.xyz} @{set2.xyz + ").append (JU.Escape.eP (vt2)).append ("*0.9} color green");
 draw1.append (drawid).append ("offsetFrameZ diameter 0.20 @{set2.xyz} @{set2.xyz + ").append (JU.Escape.eP (vt3)).append ("*0.9} color purple");
-draw1.append ("\n}\n");
+}draw1.append ("\n}\n");
 cmds = draw1.toString ();
 if (JU.Logger.debugging) JU.Logger.info (cmds);
 draw1 = null;
@@ -506,7 +532,7 @@ m2.m23 += vtrans.z;
 }xyzNew = (op.isBio ? m2.toString () : op.modDim > 0 ? op.xyzOriginal : JS.SymmetryOperation.getXYZFromMatrix (m2, false, false, false));
 if (op.timeReversal != 0) xyzNew = op.fixMagneticXYZ (m2, xyzNew, true);
 return  Clazz.newArray (-1, [xyzNew, op.xyzOriginal, info1, cmds, JS.SymmetryDesc.approx0 (ftrans), JS.SymmetryDesc.approx0 (trans), JS.SymmetryDesc.approx0 (ipt), JS.SymmetryDesc.approx0 (pa1), plane == null ? JS.SymmetryDesc.approx0 (ax1) : null, ang1 != 0 ? Integer.$valueOf (ang1) : null, m2, vtrans.lengthSquared () > 0 ? vtrans : null, op.getCentering (), Integer.$valueOf (op.timeReversal), plane, type, Integer.$valueOf (op.index)]);
-}, "JS.SymmetryOperation,J.api.SymmetryInterface,JU.P3,JU.P3,~S,~N");
+}, "JS.SymmetryOperation,J.api.SymmetryInterface,JU.P3,JU.P3,~S,~N,~N");
 c$.drawLine = Clazz.defineMethod (c$, "drawLine", 
  function (s, id, diameter, pt0, pt1, color) {
 s.append (id).append (" diameter ").appendF (diameter).append (JU.Escape.eP (pt0)).append (JU.Escape.eP (pt1)).append (" color ").append (color);
@@ -558,15 +584,17 @@ pt.z = JS.SymmetryOperation.approxF (pt.z);
 }return pt;
 }, "JU.T3");
 Clazz.defineMethod (c$, "getSymmetryInfo", 
- function (sym, iModel, iatom, uc, xyz, op, pt, pt2, id, type, scaleFactor, nth) {
+ function (sym, iModel, iatom, uc, xyz, op, pt, pt2, id, type, scaleFactor, nth, options) {
 if (type == 1073741994) return uc.getLatticeType ();
-var ret = (type == 135176 ? "draw ID sym_* delete" : type == 1140850689 ?  new JU.BS () : "");
+var nullRet = JS.SymmetryDesc.nullReturn (type);
 var iop = op;
+var offset = (options == 1073742066 && (type == 1140850689 || type == 134217751) ? pt2 : null);
+if (offset != null) pt2 = null;
 var info = null;
 if (pt2 == null) {
 if (xyz == null) {
 var ops = uc.getSymmetryOperations ();
-if (ops == null || op == 0 || Math.abs (op) > ops.length) return ret;
+if (ops == null || op == 0 || Math.abs (op) > ops.length) return nullRet;
 iop = Math.abs (op) - 1;
 xyz = ops[iop].xyz;
 } else {
@@ -575,26 +603,34 @@ iop = op = 0;
 symTemp.setSpaceGroup (false);
 var isBio = uc.isBio ();
 var i = (isBio ? symTemp.addBioMoleculeOperation (uc.spaceGroup.finalOperations[iop], op < 0) : symTemp.addSpaceGroupOperation ((op < 0 ? "!" : "=") + xyz, Math.abs (op)));
-if (i < 0) return ret;
+if (i < 0) return nullRet;
 var opTemp = symTemp.getSpaceGroupOperation (i);
 opTemp.index = op - 1;
 if (!isBio) opTemp.getCentering ();
 if (pt == null && iatom >= 0) pt = this.modelSet.at[iatom];
 if (type == 134217751 || type == 1140850689) {
-if (isBio) return ret;
+if (isBio) return nullRet;
 symTemp.setUnitCell (uc);
 pt = JU.P3.newP (pt);
 uc.toFractional (pt, false);
-if (Float.isNaN (pt.x)) return ret;
+if (Float.isNaN (pt.x)) return nullRet;
 var sympt =  new JU.P3 ();
 symTemp.newSpaceGroupPoint (i, pt, sympt, 0, 0, 0, null);
-symTemp.toCartesian (sympt, false);
+if (options == 1073742066) {
+uc.unitize (sympt);
+if (options == 1073742066) sympt.add (offset);
+}symTemp.toCartesian (sympt, false);
 return (type == 1140850689 ? this.getAtom (uc, iModel, iatom, sympt) : sympt);
-}info = this.createInfoArray (opTemp, uc, pt, pt2, (id == null ? "sym" : id), scaleFactor);
+}info = this.createInfoArray (opTemp, uc, pt, null, (id == null ? "sym" : id), scaleFactor, options);
 } else {
 var stype = "info";
 var asString = false;
 switch (type) {
+case 1275068418:
+id = stype = null;
+asString = false;
+if (nth == 0) nth = -1;
+break;
 case 1073742001:
 id = stype = null;
 asString = true;
@@ -610,15 +646,21 @@ id = stype = null;
 default:
 if (nth == 0) nth = 1;
 }
-ret = this.getSymopInfoForPoints (sym, iModel, op, pt, pt2, id, stype, scaleFactor, nth, asString);
-if (asString) return ret;
-if (Clazz.instanceOf (ret, String)) return null;
-info = ret;
+var ret1 = this.getSymopInfoForPoints (sym, iModel, op, pt, pt2, id, stype, scaleFactor, nth, asString, options);
+if (asString) return ret1;
+if (Clazz.instanceOf (ret1, String)) return nullRet;
+info = ret1;
 if (type == 1140850689) {
 if (!(Clazz.instanceOf (pt, JM.Atom)) && !(Clazz.instanceOf (pt2, JM.Atom))) iatom = -1;
-return (info == null ?  new JU.BS () : this.getAtom (uc, iModel, iatom, info[7]));
-}}return JS.SymmetryDesc.getInfo (info, type);
-}, "JS.Symmetry,~N,~N,JS.Symmetry,~S,~N,JU.P3,JU.P3,~S,~N,~N,~N");
+return (info == null ? nullRet : this.getAtom (uc, iModel, iatom, info[7]));
+}}if (info == null) return nullRet;
+if (type == 1275068418 && nth < 0 && op <= 0) {
+var lst =  new JU.Lst ();
+for (var i = 0; i < info.length; i++) lst.add (JS.SymmetryDesc.getInfo (info[i], 1275068418));
+
+return lst;
+}return JS.SymmetryDesc.getInfo (info, type);
+}, "JS.Symmetry,~N,~N,JS.Symmetry,~S,~N,JU.P3,JU.P3,~S,~N,~N,~N,~N");
 Clazz.defineMethod (c$, "getAtom", 
  function (uc, iModel, iAtom, sympt) {
 var bsElement = null;
@@ -635,31 +677,41 @@ if (bsElement != null) bsResult.and (bsElement);
 }return bsResult;
 }, "JS.Symmetry,~N,~N,JU.T3");
 Clazz.defineMethod (c$, "getSymopInfoForPoints", 
- function (sym, modelIndex, symOp, pt1, pt2, drawID, stype, scaleFactor, nth, asString) {
-var strOperations = "";
-var infolist;
+ function (sym, modelIndex, symOp, pt1, pt2, drawID, stype, scaleFactor, nth, asString, options) {
 var ret = (asString ? "" : null);
-var sginfo = this.getSpaceGroupInfo (sym, modelIndex, null, symOp, pt1, pt2, drawID, scaleFactor, nth, false, true);
+var sginfo = this.getSpaceGroupInfo (sym, modelIndex, null, symOp, pt1, pt2, drawID, scaleFactor, nth, false, true, options);
 if (sginfo == null) return ret;
-strOperations = sginfo.get ("symmetryInfo");
-infolist = sginfo.get ("operations");
+var infolist = sginfo.get ("operations");
 if (infolist == null) return ret;
-var sb =  new JU.SB ();
+var sb = (asString ?  new JU.SB () : null);
 symOp--;
+var isAll = (!asString && symOp < 0);
+var strOperations = sginfo.get ("symmetryInfo");
 var labelOnly = "label".equals (stype);
+var n = 0;
 for (var i = 0; i < infolist.length; i++) {
 if (infolist[i] == null || symOp >= 0 && symOp != i) continue;
-if (!asString) return infolist[i];
-if (drawID != null) return (infolist[i][3]) + "\nprint " + JU.PT.esc (strOperations);
+if (!asString) {
+if (!isAll) return infolist[i];
+infolist[n++] = infolist[i];
+continue;
+}if (drawID != null) return (infolist[i][3]) + "\nprint " + JU.PT.esc (strOperations);
 if (sb.length () > 0) sb.appendC ('\n');
 if (!labelOnly) {
 if (symOp < 0) sb.appendI (i + 1).appendC ('\t');
 sb.append (infolist[i][0]).appendC ('\t');
 }sb.append (infolist[i][2]);
 }
-if (sb.length () == 0) return (drawID != null ? "draw " + drawID + "* delete" : ret);
+if (!asString) {
+var a =  new Array (n);
+for (var i = 0; i < n; i++) a[i] = infolist[i];
+
+return a;
+}if (sb.length () == 0) return (drawID != null ? "draw " + drawID + "* delete" : ret);
 return sb.toString ();
-}, "JS.Symmetry,~N,~N,JU.P3,JU.P3,~S,~S,~N,~N,~B");
+}, "JS.Symmetry,~N,~N,JU.P3,JU.P3,~S,~S,~N,~N,~B,~N");
 Clazz.defineStatics (c$,
-"keys",  Clazz.newArray (-1, ["xyz", "xyzOriginal", "label", null, "fractionalTranslation", "cartesianTranslation", "inversionCenter", null, "axisVector", "rotationAngle", "matrix", "unitTranslation", "centeringVector", "timeReversal", "plane", "_type", "id"]));
+"keys",  Clazz.newArray (-1, ["xyz", "xyzOriginal", "label", null, "fractionalTranslation", "cartesianTranslation", "inversionCenter", null, "axisVector", "rotationAngle", "matrix", "unitTranslation", "centeringVector", "timeReversal", "plane", "_type", "id"]),
+"KEY_DRAW", 3,
+"KEY_POINT", 7);
 });
