@@ -301,8 +301,8 @@ if (fileName != null) {
 fileName = this.setFullPath (params, this.getOutputFileNameFromDialog (fileName, -2147483648, null));
 if (fileName == null) return null;
 }this.vwr.mustRender = true;
-var saveWidth = this.vwr.dimScreen.width;
-var saveHeight = this.vwr.dimScreen.height;
+var saveWidth = this.vwr.screenWidth;
+var saveHeight = this.vwr.screenHeight;
 this.vwr.resizeImage (width, height, true, true, false);
 this.vwr.setModelVisibility ();
 var data = this.vwr.rm.renderExport (this.vwr.gdata, this.vwr.ms, params);
@@ -311,8 +311,8 @@ return data;
 }, "java.util.Map");
 Clazz.defineMethod (c$, "getImageAsBytes", 
 function (type, width, height, quality, errMsg) {
-var saveWidth = this.vwr.dimScreen.width;
-var saveHeight = this.vwr.dimScreen.height;
+var saveWidth = this.vwr.screenWidth;
+var saveHeight = this.vwr.screenHeight;
 this.vwr.mustRender = true;
 this.vwr.resizeImage (width, height, true, false, false);
 this.vwr.setModelVisibility ();
@@ -412,8 +412,8 @@ fileName = this.setFullPath (params, fileName);
 }if (fileName == null) return null;
 params.put ("fileName", fileName);
 if (JU.OC.isLocal (fileName)) localName = fileName;
-saveWidth = this.vwr.dimScreen.width;
-saveHeight = this.vwr.dimScreen.height;
+saveWidth = this.vwr.screenWidth;
+saveHeight = this.vwr.screenHeight;
 this.vwr.creatingImage = true;
 if (mustRender) {
 this.vwr.mustRender = true;
