@@ -1,4 +1,4 @@
-(function(C,D,E,F,G,H,q,r,t,u,v,p,I,w,K,s,x,y,L,z,A,B,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$,aa,ba,ca,da,ea,fa,ga,ha,ia,ja,ka,la,ma,na,oa,pa,qa,ra,sa,ta,ua,h,l){q("JV");c$=z(JV,"JmolStateCreator");q("JV");t(["JV.JmolStateCreator","java.util.Hashtable"],"JV.StateCreator","java.lang.Float java.util.Arrays $.Date javajs.awt.Font JU.BS $.P3 $.PT $.SB J.c.PAL $.STR $.VDW JM.Atom $.AtomCollection $.Bond $.BondSet JS.T J.shape.Shape JU.BSUtil $.C $.ColorEncoder $.Edge $.Escape $.Logger JV.GlobalSettings $.JC $.StateManager $.Viewer".split(" "),
+(function(C,D,E,F,G,H,q,r,t,u,v,p,I,w,K,s,x,y,L,z,A,B,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$,aa,ba,ca,da,ea,fa,ga,ha,ia,ja,ka,la,ma,na,oa,pa,qa,ra,sa,ta,ua,h,l){q("JV");c$=z(JV,"JmolStateCreator");q("JV");t(["JV.JmolStateCreator","java.util.Hashtable"],"JV.StateCreator","java.lang.Float java.util.Arrays $.Date JU.BS $.P3 $.PT $.SB J.c.PAL $.STR $.VDW JM.Atom $.AtomCollection $.Bond $.BondSet JS.T J.shape.Shape JU.BSUtil $.C $.ColorEncoder $.Edge $.Escape $.Font $.Logger JV.GlobalSettings $.JC $.StateManager $.Viewer".split(" "),
 function(){c$=v(function(){this.temp3=this.temp2=this.temp=this.vwr=null;this.undoWorking=!1;u(this,arguments)},JV,"StateCreator",JV.JmolStateCreator);A(c$,function(){this.temp=new java.util.Hashtable;this.temp2=new java.util.Hashtable;this.temp3=new java.util.Hashtable});w(c$,function(){B(this,JV.StateCreator,[])});l(c$,"setViewer",function(a){this.vwr=a},"JV.Viewer");l(c$,"getStateScript",function(a,b,c){var d=null==a||a.equalsIgnoreCase("all"),e=new JU.SB,f=d?(new JU.SB).append("function _setState() {\n"):
 null;d&&(e.append("# Jmol state version "+JV.Viewer.getJmolVersion()+";\n"),this.vwr.isApplet&&(this.app(e,"# fullName = "+JU.PT.esc(this.vwr.fullName)),this.app(e,"# documentBase = "+JU.PT.esc(JV.Viewer.appletDocumentBase)),this.app(e,"# codeBase = "+JU.PT.esc(JV.Viewer.appletCodeBase)),e.append("\n")));var g=this.vwr.g;(d||a.equalsIgnoreCase("windowState"))&&e.append(this.getWindowState(f,b,c));(d||a.equalsIgnoreCase("fileState"))&&e.append(this.getFileState(f));(d||a.equalsIgnoreCase("definedState"))&&
 e.append(this.getDefinedState(f,!0));(d||a.equalsIgnoreCase("variableState"))&&e.append(this.getParameterState(g,f));(d||a.equalsIgnoreCase("dataState"))&&e.append(this.getDataState(f));(d||a.equalsIgnoreCase("modelState"))&&e.append(this.getModelState(f,!0,this.vwr.getBooleanProperty("saveProteinStructureState")));(d||a.equalsIgnoreCase("colorState"))&&e.append(this.getColorState(this.vwr.cm,f));(d||a.equalsIgnoreCase("frameState"))&&e.append(this.getAnimState(this.vwr.am,f));(d||a.equalsIgnoreCase("perspectiveState"))&&
@@ -25,7 +25,7 @@ return d.toString()},"JV.AnimationManager,JU.SB");h(c$,"getParameterState",funct
 ((f=g.next())||1);)if(JV.GlobalSettings.doReportProperty(f)){var k=a.htNonbooleanParameterValues.get(f);"="==f.charAt(0)?f=f.substring(1):(f=(0==f.indexOf("default")?" ":"")+"set "+f,k=JU.Escape.e(k));c[e++]=f+" "+k}switch(a.axesMode){case 603979808:c[e++]="set axes unitcell";break;case 603979804:c[e++]="set axes molecular";break;default:c[e++]="set axes window"}java.util.Arrays.sort(c,0,e);for(f=0;f<e;f++)null!=c[f]&&this.app(d,c[f]);c=JV.StateManager.getVariableList(a.htUserVariables,0,!1,!0);0<
 c.length&&(d.append("\n#user-defined atom sets; \n"),d.append(c));null!=this.vwr.shm.getShape(5)&&d.append(this.getDefaultLabelState(this.vwr.shm.shapes[5]));a.haveSetStructureList&&(c=a.structureList,d.append("struture HELIX set "+JU.Escape.eAF(c.get(J.c.STR.HELIX))),d.append("struture SHEET set "+JU.Escape.eAF(c.get(J.c.STR.SHEET))),d.append("struture TURN set "+JU.Escape.eAF(c.get(J.c.STR.TURN))));null!=b&&d.append("\n}\n\n");return d.toString()},"JV.GlobalSettings,JU.SB");h(c$,"getDefaultLabelState",
 function(a){var b=(new JU.SB).append("\n# label defaults;\n");this.app(b,"select none");this.app(b,J.shape.Shape.getColorCommand("label",a.defaultPaletteID,a.defaultColix,a.translucentAllowed));this.app(b,"background label "+J.shape.Shape.encodeColor(a.defaultBgcolix));this.app(b,"set labelOffset "+JV.JC.getXOffset(a.defaultOffset)+" "+JV.JC.getYOffset(a.defaultOffset));var c=JV.JC.getHorizAlignmentName(a.defaultAlignment);this.app(b,"set labelAlignment "+(5>c.length?"left":c));c=JV.JC.getPointerName(a.defaultPointer);
-this.app(b,"set labelPointer "+(0==c.length?"off":c));0!=(a.defaultZPos&32)?this.app(b,"set labelFront"):0!=(a.defaultZPos&16)&&this.app(b,"set labelGroup");this.app(b,J.shape.Shape.getFontCommand("label",javajs.awt.Font.getFont3D(a.defaultFontId)));return b.toString()},"J.shape.Labels");h(c$,"getSelectionState",function(a,b){var c=new JU.SB;null!=b&&(b.append("  _setSelectionState;\n"),c.append("function _setSelectionState() {\n"));null!=this.vwr.ms.trajectory&&this.app(c,this.vwr.ms.trajectory.getState());
+this.app(b,"set labelPointer "+(0==c.length?"off":c));0!=(a.defaultZPos&32)?this.app(b,"set labelFront"):0!=(a.defaultZPos&16)&&this.app(b,"set labelGroup");this.app(b,J.shape.Shape.getFontCommand("label",JU.Font.getFont3D(a.defaultFontId)));return b.toString()},"J.shape.Labels");h(c$,"getSelectionState",function(a,b){var c=new JU.SB;null!=b&&(b.append("  _setSelectionState;\n"),c.append("function _setSelectionState() {\n"));null!=this.vwr.ms.trajectory&&this.app(c,this.vwr.ms.trajectory.getState());
 var d=new java.util.Hashtable,e=null;this.addBs(c,"hide ",a.bsHidden);this.addBs(c,"subset ",a.bsSubset);this.addBs(c,"delete ",a.bsDeleted);this.addBs(c,"fix ",a.bsFixed);d.put("-",this.vwr.slm.getSelectedAtomsNoSubset());e=this.getCommands(d,null,"select");null==e?this.app(c,"select none"):c.append(e);this.app(c,"set hideNotSelected "+a.hideNotSelected);c.append(this.vwr.getShapeProperty(1,"selectionState"));this.vwr.getSelectionHalosEnabled()&&this.app(c,"SelectionHalos ON");null!=b&&c.append("}\n\n");
 return c.toString()},"JV.SelectionManager,JU.SB");h(c$,"getViewState",function(a,b){var c=new JU.SB,d=a.getMoveToText(0,!1);null!=b&&(b.append("  _setPerspectiveState;\n"),c.append("function _setPerspectiveState() {\n"));this.app(c,"set perspectiveModel "+a.perspectiveModel);this.app(c,"set scaleAngstromsPerInch "+a.scale3DAngstromsPerInch);this.app(c,"set perspectiveDepth "+a.perspectiveDepth);this.app(c,"set visualRange "+a.visualRangeAngstroms);a.isWindowCentered()||this.app(c,"set windowCentered false");
 this.app(c,"set cameraDepth "+a.cameraDepth);var e=1==a.mode;e&&this.app(c,"set navigationMode true");this.app(c,this.vwr.ms.getBoundBoxCommand(!1));this.app(c,"center "+JU.Escape.eP(a.fixedRotationCenter));c.append(this.vwr.getOrientationText(1073742034,null,null).toString());this.app(c,d);!e&&!a.zoomEnabled&&this.app(c,"zoom off");c.append("  slab ").appendI(a.slabPercentSetting).append(";depth ").appendI(a.depthPercentSetting).append(a.slabEnabled&&!e?";slab on":"").append(";\n");c.append("  set slabRange ").appendF(a.slabRange).append(";\n");
@@ -34,20 +34,20 @@ null!=b&&c.append("}\n\n");return c.toString()},"JV.TransformManager,JU.SB");h(c
 b="  set spinX "+p(a.spinX)+"; set spinY "+p(a.spinY)+"; set spinZ "+p(a.spinZ)+"; set spinFps "+p(a.spinFps)+";";Float.isNaN(a.navFps)||(b+="  set navX "+p(a.navX)+"; set navY "+p(a.navY)+"; set navZ "+p(a.navZ)+"; set navFps "+p(a.navFps)+";");a.navOn&&(b+=" navigation on;");if(!a.spinOn)return b;var c=a.isSpinSelected?"\n  select "+JU.Escape.eBS(this.vwr.bsA())+";\n  rotateSelected":"\n ";if(a.isSpinInternal){var d=JU.P3.newP(a.internalRotationCenter);d.sub(a.rotationAxis);b+=c+" spin "+a.rotationRate+
 " "+JU.Escape.eP(a.internalRotationCenter)+" "+JU.Escape.eP(d)}else b=a.isSpinFixed?b+(c+" spin axisangle "+JU.Escape.eP(a.rotationAxis)+" "+a.rotationRate):b+" spin on";return b+";"},"~B");l(c$,"getCommands",function(a,b,c){var d=new JU.SB;a=this.getCommands2(a,d,null,c);null!=b&&this.getCommands2(b,d,a,"select");return d.toString()},"java.util.Map,java.util.Map,~S");h(c$,"getCommands2",function(a,b,c,d){if(null==a)return"";var e;for(a=a.entrySet().iterator();a.hasNext()&&((e=a.next())||1);){var f=
 e.getKey(),g=JU.Escape.eBS(e.getValue());5>g.length||(g=d+" "+g,g.equals(c)||this.app(b,g),c=g,0!=f.indexOf("-")&&this.app(b,f))}return c},"java.util.Map,JU.SB,~S,~S");h(c$,"app",function(a,b){0!=b.length&&a.append("  ").append(b).append(";\n")},"JU.SB,~S");h(c$,"addBs",function(a,b,c){null==c||0==c.length()||this.app(a,b+JU.Escape.eBS(c))},"JU.SB,~S,JU.BS");h(c$,"getFontState",function(a,b){var c=JV.StateManager.getObjectIdFromName(a.equalsIgnoreCase("axes")?"axis":a);if(0>c)return"";var d=this.vwr.getObjectMad10(c),
-c=(new JU.SB).append("\n");this.app(c,a+(0==d?" off":1==d?" on":-1==d?" dotted":20>d?" "+d:" "+d/2E4));if(3>c.length())return"";d=J.shape.Shape.getFontCommand(a,b);0<d.length&&(d="  "+d+";\n");return c+d},"~S,javajs.awt.Font");h(c$,"appendTickInfo",function(a,b,c){b.append("  ");b.append(a);JV.StateCreator.addTickInfo(b,c,!1);b.append(";\n")},"~S,JU.SB,JM.TickInfo");c$.addTickInfo=h(c$,"addTickInfo",function(a,b,c){a.append(" ticks ").append(b.type).append(" ").append(JU.Escape.eP(b.ticks));var d=
-null!=b.scale&&Float.isNaN(b.scale.x);d&&a.append(" UNITCELL");null!=b.tickLabelFormats&&a.append(" format ").append(JU.Escape.eAS(b.tickLabelFormats,!1));!d&&null!=b.scale&&a.append(" scale ").append(JU.Escape.eP(b.scale));c&&(!Float.isNaN(b.first)&&0!=b.first)&&a.append(" first ").appendF(b.first);null!=b.reference&&a.append(" point ").append(JU.Escape.eP(b.reference))},"JU.SB,JM.TickInfo,~B");h(c$,"getMeasurementState",function(a){var b=a.measurements,c=a.measurementCount,d=a.font3d,e=a.defaultTickInfo,
-f=new JU.SB;this.app(f,"measures delete");for(var g=0;g<c;g++){var k=b.get(g),n=k.count,h=(new JU.SB).append("measure");null!=k.thisID&&h.append(" ID ").append(JU.PT.esc(k.thisID));0!=k.mad&&h.append(" radius ").appendF(null==k.thisID||0<k.mad?k.mad/2E3:0);0!=k.colix&&h.append(" color ").append(JU.Escape.escapeColor(JU.C.getArgb(k.colix)));null!=k.text&&(null!=k.text.font&&h.append(" font ").append(k.text.font.getInfo()),0!=k.text.align&&h.append(" align ").append(JV.JC.getHorizAlignmentName(k.text.align)),
-null!=k.text.pymolOffset&&h.append(" offset ").append(JU.Escape.eAF(k.text.pymolOffset)));var j=k.tickInfo;null!=j&&JV.StateCreator.addTickInfo(h,j,!0);for(j=1;j<=n;j++)h.append(" ").append(k.getLabel(j,!0,!0));h.append("; # "+a.getInfoAsString(g));this.app(f,h.toString())}this.app(f,"select *; set measures "+this.vwr.g.measureDistanceUnits);this.app(f,J.shape.Shape.getFontCommand("measures",d));d=0;n=new java.util.Hashtable;h=JU.BS.newN(c);for(g=0;g<c;g++)k=b.get(g),k.isHidden&&(d++,h.set(g)),null!=
-a.bsColixSet&&a.bsColixSet.get(g)&&JU.BSUtil.setMapBitSet(n,g,g,J.shape.Shape.getColorCommandUnk("measure",k.colix,a.translucentAllowed)),null!=k.strFormat&&JU.BSUtil.setMapBitSet(n,g,g,"measure "+JU.PT.esc(k.strFormat));if(0<d)if(d==c)this.app(f,"measures off; # lines and numbers off");else for(g=0;g<c;g++)h.get(g)&&JU.BSUtil.setMapBitSet(n,g,g,"measure off");null!=e&&(f.append(" measure "),JV.StateCreator.addTickInfo(f,e,!0),f.append(";\n"));0<=a.mad&&f.append(" set measurements ").appendF(a.mad/
-2E3).append(";\n");a=this.getCommands(n,null,"select measures");null!=a&&0!=a.length&&(f.append(a),this.app(f,"select measures ({null})"));return f.toString()},"J.shape.Measures");h(c$,"getShapeStatePriv",function(a,b,c){var d=this.vwr.shm.shapes;if(null!=d){var e;2147483647==c?(c=0,e=37):e=c+1;for(;c<e;++c){var f=d[c];if(null!=f&&(b||9<=c&&16>c))f=this.getShapeState(f),null!=f&&1<f.length&&a.append(f)}a.append("  select *;\n")}},"JU.SB,~B,~N");h(c$,"getBondState",function(a){var b=a.bsOrderSet,c=
-a.reportAll;this.clearTemp();var d=this.vwr.ms,e=d.bo,f=d.bondCount,g;if(c||null!=a.bsSizeSet)for(d=c?f-1:a.bsSizeSet.nextSetBit(0);0<=d;d=c?d-1:a.bsSizeSet.nextSetBit(d+1))JU.BSUtil.setMapBitSet(this.temp,d,d,"wireframe "+(1==(g=e[d].mad)?"on":""+JU.PT.escF(g/2E3)));if(c||null!=b)for(d=c?f-1:b.nextSetBit(0);0<=d;d=c?d-1:b.nextSetBit(d+1))g=e[d],(c||0==(g.order&131072))&&JU.BSUtil.setMapBitSet(this.temp,d,d,"bondOrder "+JU.Edge.getBondOrderNameFromOrder(g.order));if(null!=a.bsColixSet)for(d=a.bsColixSet.nextSetBit(0);0<=
-d;d=a.bsColixSet.nextSetBit(d+1))b=e[d].colix,2==(b&-30721)?JU.BSUtil.setMapBitSet(this.temp,d,d,J.shape.Shape.getColorCommand("bonds",J.c.PAL.CPK.id,b,a.translucentAllowed)):JU.BSUtil.setMapBitSet(this.temp,d,d,J.shape.Shape.getColorCommandUnk("bonds",b,a.translucentAllowed));a=this.getCommands(this.temp,null,"select BONDS")+"\n";this.clearTemp();return a},"J.shape.Sticks");h(c$,"clearTemp",function(){this.temp.clear();this.temp2.clear()});h(c$,"getShapeState",function(a){var b;switch(a.shapeID){case 34:b=
+c=(new JU.SB).append("\n");this.app(c,a+(0==d?" off":1==d?" on":-1==d?" dotted":20>d?" "+d:" "+d/2E4));if(3>c.length())return"";d=J.shape.Shape.getFontCommand(a,b);0<d.length&&(d="  "+d+";\n");return c+d},"~S,JU.Font");h(c$,"appendTickInfo",function(a,b,c){b.append("  ");b.append(a);JV.StateCreator.addTickInfo(b,c,!1);b.append(";\n")},"~S,JU.SB,JM.TickInfo");c$.addTickInfo=h(c$,"addTickInfo",function(a,b,c){a.append(" ticks ").append(b.type).append(" ").append(JU.Escape.eP(b.ticks));var d=null!=b.scale&&
+Float.isNaN(b.scale.x);d&&a.append(" UNITCELL");null!=b.tickLabelFormats&&a.append(" format ").append(JU.Escape.eAS(b.tickLabelFormats,!1));!d&&null!=b.scale&&a.append(" scale ").append(JU.Escape.eP(b.scale));c&&(!Float.isNaN(b.first)&&0!=b.first)&&a.append(" first ").appendF(b.first);null!=b.reference&&a.append(" point ").append(JU.Escape.eP(b.reference))},"JU.SB,JM.TickInfo,~B");h(c$,"getMeasurementState",function(a){var b=a.measurements,c=a.measurementCount,d=a.font3d,e=a.defaultTickInfo,f=new JU.SB;
+this.app(f,"measures delete");for(var g=0;g<c;g++){var k=b.get(g),n=k.count,h=(new JU.SB).append("measure");null!=k.thisID&&h.append(" ID ").append(JU.PT.esc(k.thisID));0!=k.mad&&h.append(" radius ").appendF(null==k.thisID||0<k.mad?k.mad/2E3:0);0!=k.colix&&h.append(" color ").append(JU.Escape.escapeColor(JU.C.getArgb(k.colix)));null!=k.text&&(null!=k.text.font&&h.append(" font ").append(k.text.font.getInfo()),0!=k.text.align&&h.append(" align ").append(JV.JC.getHorizAlignmentName(k.text.align)),null!=
+k.text.pymolOffset&&h.append(" offset ").append(JU.Escape.eAF(k.text.pymolOffset)));var j=k.tickInfo;null!=j&&JV.StateCreator.addTickInfo(h,j,!0);for(j=1;j<=n;j++)h.append(" ").append(k.getLabel(j,!0,!0));h.append("; # "+a.getInfoAsString(g));this.app(f,h.toString())}this.app(f,"select *; set measures "+this.vwr.g.measureDistanceUnits);this.app(f,J.shape.Shape.getFontCommand("measures",d));d=0;n=new java.util.Hashtable;h=JU.BS.newN(c);for(g=0;g<c;g++)k=b.get(g),k.isHidden&&(d++,h.set(g)),null!=a.bsColixSet&&
+a.bsColixSet.get(g)&&JU.BSUtil.setMapBitSet(n,g,g,J.shape.Shape.getColorCommandUnk("measure",k.colix,a.translucentAllowed)),null!=k.strFormat&&JU.BSUtil.setMapBitSet(n,g,g,"measure "+JU.PT.esc(k.strFormat));if(0<d)if(d==c)this.app(f,"measures off; # lines and numbers off");else for(g=0;g<c;g++)h.get(g)&&JU.BSUtil.setMapBitSet(n,g,g,"measure off");null!=e&&(f.append(" measure "),JV.StateCreator.addTickInfo(f,e,!0),f.append(";\n"));0<=a.mad&&f.append(" set measurements ").appendF(a.mad/2E3).append(";\n");
+a=this.getCommands(n,null,"select measures");null!=a&&0!=a.length&&(f.append(a),this.app(f,"select measures ({null})"));return f.toString()},"J.shape.Measures");h(c$,"getShapeStatePriv",function(a,b,c){var d=this.vwr.shm.shapes;if(null!=d){var e;2147483647==c?(c=0,e=37):e=c+1;for(;c<e;++c){var f=d[c];if(null!=f&&(b||9<=c&&16>c))f=this.getShapeState(f),null!=f&&1<f.length&&a.append(f)}a.append("  select *;\n")}},"JU.SB,~B,~N");h(c$,"getBondState",function(a){var b=a.bsOrderSet,c=a.reportAll;this.clearTemp();
+var d=this.vwr.ms,e=d.bo,f=d.bondCount,g;if(c||null!=a.bsSizeSet)for(d=c?f-1:a.bsSizeSet.nextSetBit(0);0<=d;d=c?d-1:a.bsSizeSet.nextSetBit(d+1))JU.BSUtil.setMapBitSet(this.temp,d,d,"wireframe "+(1==(g=e[d].mad)?"on":""+JU.PT.escF(g/2E3)));if(c||null!=b)for(d=c?f-1:b.nextSetBit(0);0<=d;d=c?d-1:b.nextSetBit(d+1))g=e[d],(c||0==(g.order&131072))&&JU.BSUtil.setMapBitSet(this.temp,d,d,"bondOrder "+JU.Edge.getBondOrderNameFromOrder(g.order));if(null!=a.bsColixSet)for(d=a.bsColixSet.nextSetBit(0);0<=d;d=
+a.bsColixSet.nextSetBit(d+1))b=e[d].colix,2==(b&-30721)?JU.BSUtil.setMapBitSet(this.temp,d,d,J.shape.Shape.getColorCommand("bonds",J.c.PAL.CPK.id,b,a.translucentAllowed)):JU.BSUtil.setMapBitSet(this.temp,d,d,J.shape.Shape.getColorCommandUnk("bonds",b,a.translucentAllowed));a=this.getCommands(this.temp,null,"select BONDS")+"\n";this.clearTemp();return a},"J.shape.Sticks");h(c$,"clearTemp",function(){this.temp.clear();this.temp2.clear()});h(c$,"getShapeState",function(a){var b;switch(a.shapeID){case 34:b=
 this.getAxesState(a);break;case 33:if(!this.vwr.ms.haveUnitCells)return"";a=b=this.getFontLineShapeState(a);var c=this.vwr.am.cai;0<=c&&(b+="  unitcell ({"+c+"});\n");c=this.vwr.getCurrentUnitCell();null!=c&&(b+=c.getUnitCellState(),b+=a);break;case 32:b=this.getFontLineShapeState(a);break;case 36:b=this.getFontState(a.myType,a.baseFont3d);break;case 6:b=this.getMeasurementState(a);break;case 7:case 18:b=this.getAtomShapeState(a);break;case 1:b=this.getBondState(a);break;case 31:b=new JU.SB;b.append("\n  set echo off;\n");
 for(a=a.objects.values().iterator();a.hasNext()&&((c=a.next())||1);)b.append(this.getTextState(c)),c.hidden&&b.append("  set echo ID ").append(JU.PT.esc(c.target)).append(" hidden;\n");b=b.toString();break;case 8:b=this.getAtomShapeState(a)+(2==a.colixSelection?"":0==a.colixSelection?"  color SelectionHalos NONE;\n":J.shape.Shape.getColorCommandUnk("selectionHalos",a.colixSelection,a.translucentAllowed)+";\n");null!=a.bsHighlight&&(b+="  set highlight "+JU.Escape.eBS(a.bsHighlight)+"; "+J.shape.Shape.getColorCommandUnk("highlight",
 a.colixHighlight,a.translucentAllowed)+";\n");break;case 35:this.clearTemp();if(null!=a.atomFormats)for(b=this.vwr.ms.ac;0<=--b;)null!=a.atomFormats[b]&&JU.BSUtil.setMapBitSet(this.temp,b,b,"set hoverLabel "+JU.PT.esc(a.atomFormats[b]));b="\n  hover "+JU.PT.esc(null==a.labelFormat?"":a.labelFormat)+";\n"+this.getCommands(this.temp,null,"select");this.clearTemp();break;case 5:if(!a.isActive||null==a.bsSizeSet)return"";this.clearTemp();for(b=a.bsSizeSet.nextSetBit(0);0<=b;b=a.bsSizeSet.nextSetBit(b+
 1)){var c=a.getLabel(b),d="label ";null==c?d+=JU.PT.esc(a.formats[b]):(d+=JU.PT.esc(c.textUnformatted),null!=c.pymolOffset&&(d+=";set labelOffset "+JU.Escape.eAF(c.pymolOffset)));JU.BSUtil.setMapBitSet(this.temp,b,b,d);null!=a.bsColixSet&&a.bsColixSet.get(b)&&JU.BSUtil.setMapBitSet(this.temp2,b,b,J.shape.Shape.getColorCommand("label",a.paletteIDs[b],a.colixes[b],a.translucentAllowed));null!=a.bsBgColixSet&&a.bsBgColixSet.get(b)&&JU.BSUtil.setMapBitSet(this.temp2,b,b,"background label "+J.shape.Shape.encodeColor(a.bgcolixes[b]));
 c=a.getLabel(b);c=null!=c?c.scalePixelsPerMicron:0;0<c&&JU.BSUtil.setMapBitSet(this.temp2,b,b,"set labelScaleReference "+1E4/c);if(null!=a.offsets&&a.offsets.length>b){c=a.offsets[b];JU.BSUtil.setMapBitSet(this.temp2,b,b,"set "+(JV.JC.isOffsetAbsolute(c)?"labelOffsetAbsolute ":"labelOffset ")+JV.JC.getXOffset(c)+" "+JV.JC.getYOffset(c));var d=JV.JC.getHorizAlignmentName(c>>2),e=JV.JC.getPointerName(c);0<e.length&&JU.BSUtil.setMapBitSet(this.temp2,b,b,"set labelPointer "+e);0!=(c&32)?JU.BSUtil.setMapBitSet(this.temp2,
-b,b,"set labelFront"):0!=(c&16)&&JU.BSUtil.setMapBitSet(this.temp2,b,b,"set labelGroup");0<d.length&&JU.BSUtil.setMapBitSet(this.temp3,b,b,"set labelAlignment "+d)}null!=a.mads&&0>a.mads[b]&&JU.BSUtil.setMapBitSet(this.temp2,b,b,"set toggleLabel");null!=a.bsFontSet&&a.bsFontSet.get(b)&&JU.BSUtil.setMapBitSet(this.temp2,b,b,J.shape.Shape.getFontCommand("label",javajs.awt.Font.getFont3D(a.fids[b])))}b=this.getCommands(this.temp,this.temp2,"select")+this.getCommands(null,this.temp3,"select");this.temp3.clear();
+b,b,"set labelFront"):0!=(c&16)&&JU.BSUtil.setMapBitSet(this.temp2,b,b,"set labelGroup");0<d.length&&JU.BSUtil.setMapBitSet(this.temp3,b,b,"set labelAlignment "+d)}null!=a.mads&&0>a.mads[b]&&JU.BSUtil.setMapBitSet(this.temp2,b,b,"set toggleLabel");null!=a.bsFontSet&&a.bsFontSet.get(b)&&JU.BSUtil.setMapBitSet(this.temp2,b,b,J.shape.Shape.getFontCommand("label",JU.Font.getFont3D(a.fids[b])))}b=this.getCommands(this.temp,this.temp2,"select")+this.getCommands(null,this.temp3,"select");this.temp3.clear();
 this.clearTemp();break;case 0:this.clearTemp();var c=this.vwr.ms.ac,d=this.vwr.ms.at,e=a.colixes,f=a.paletteIDs,g=0;for(b=0;b<c;b++)if(null!=a.bsSizeSet&&a.bsSizeSet.get(b)&&(0>(g=d[b].madAtom)?JU.BSUtil.setMapBitSet(this.temp,b,b,"Spacefill on"):JU.BSUtil.setMapBitSet(this.temp,b,b,"Spacefill "+JU.PT.escF(g/2E3))),null!=a.bsColixSet&&a.bsColixSet.get(b)){var k=d[b].paletteID;(k!=J.c.PAL.CPK.id||JU.C.isColixTranslucent(d[b].colixAtom))&&JU.BSUtil.setMapBitSet(this.temp,b,b,J.shape.Shape.getColorCommand("atoms",
 k,d[b].colixAtom,a.translucentAllowed));null!=e&&b<e.length&&JU.BSUtil.setMapBitSet(this.temp2,b,b,J.shape.Shape.getColorCommand("balls",f[b],e[b],a.translucentAllowed))}b=this.getCommands(this.temp,this.temp2,"select");this.clearTemp();break;default:b=a.getShapeState()}return b},"J.shape.Shape");h(c$,"getFontLineShapeState",function(a){var b=this.getFontState(a.myType,a.font3d);if(null==a.tickInfos)return b;var c=0<=b.indexOf(" off"),d=new JU.SB;d.append(b);for(b=0;4>b;b++)null!=a.tickInfos[b]&&
 this.appendTickInfo(a.myType,d,a.tickInfos[b]);c&&d.append("  "+a.myType+" off;\n");return d.toString()},"J.shape.FontLineShape");h(c$,"getAxesState",function(a){var b=new JU.SB;b.append(this.getFontLineShapeState(a));b.append("  axes scale ").appendF(this.vwr.getFloat(570425346)).append(";\n");null!=a.fixedOrigin&&b.append("  axes center ").append(JU.Escape.eP(a.fixedOrigin)).append(";\n");var c=a.axisXY;0!=c.z&&b.append("  axes position [").appendI(p(c.x)).append(" ").appendI(p(c.y)).append(" ").append(0>
