@@ -34,7 +34,7 @@
 // BH 2/14/2016 12:30:41 PM Info.appletLoadingImage: "j2s/img/JSmol_spinner.gif", 
    // can be set to "none" or some other image; see Jmol._hideLoadingSpinner(applet)
    // implemented only for JSmolApplet, not others
-// BH 2/14/2016 12:27:09 PM Jmol._setCursor 
+// BH 2/14/2016 12:27:09 PM Jmol.setCursor 
 // BH 2/14/2016 6:48:33 AM _setCursor() and cursor_wait   http://ajaxload.info/
 // BH 1/15/2016 4:23:14 PM adding Info.makeLiveImage
 // BH 12/30/2015 8:18:42 PM adding AMS call to database list; allowing for ?ALLOWSORIGIN? to override settings here
@@ -752,10 +752,10 @@ Jmol = (function(document) {
 	}
 	
   Jmol.playAudio = function(filePath) {
-    Jmol._playAudio(null, filePath);
+    Jmol.playAudio(null, filePath);
   }
   
-  Jmol._playAudio = function(applet, params) {
+  Jmol.playAudio = function(applet, params) {
   
     var get = (params.get ? function(key){return params.get(key)} : null);
     var put = (params.put ? function(key,val){return params.put(key,val)} : null);
@@ -975,7 +975,7 @@ Jmol = (function(document) {
 
 	Jmol._binaryTypes = ["mmtf",".gz",".bz2",".jpg",".gif",".png",".zip",".jmol",".bin",".smol",".spartan",".pmb",".mrc",".map",".ccp4",".dn6",".delphi",".omap",".pse",".dcd",".uk/pdbe/densities/"];
 
-	Jmol._isBinaryUrl = function(url) {
+	Jmol.isBinaryUrl = function(url) {
 		for (var i = Jmol._binaryTypes.length; --i >= 0;)
 			if (url.indexOf(Jmol._binaryTypes[i]) >= 0) return true;
 		return false;
@@ -983,7 +983,7 @@ Jmol = (function(document) {
 
 	Jmol._getFileData = function(fileName, fSuccess, doProcess) {
 		// use host-server PHP relay if not from this host
-		var isBinary = Jmol._isBinaryUrl(fileName);
+		var isBinary = Jmol.isBinaryUrl(fileName);
 		var isPDB = (fileName.indexOf(".gz") >= 0 && fileName.indexOf("rcsb.org") >= 0);
 		if (isPDB) {
 			// avoid unnecessary binary transfer
@@ -1087,14 +1087,14 @@ Jmol = (function(document) {
   Jmol._hideLocalFileReader = function(applet, cursor) {
     applet._localReader && Jmol.$setVisible(applet._localReader, false);
     applet._readingLocal = false;
-    Jmol._setCursor(applet, 0);
+    Jmol.setCursor(applet, 0);
   }
   
   Jmol.loadFileFromDialog = function(applet) {
-    Jmol._loadFileAsynchronously(null, applet, null, null);
+    Jmol.loadFileAsynchronously(null, applet, null, null);
   }
   
-	Jmol._loadFileAsynchronously = function(fileLoadThread, applet, fileName, appData) {
+	Jmol.loadFileAsynchronously = function(fileLoadThread, applet, fileName, appData) {
 		if (fileName && fileName.indexOf("?") != 0) {
 			// LOAD ASYNC command
 			var fileName0 = fileName;
@@ -1159,7 +1159,7 @@ Jmol = (function(document) {
     }    
   }
 
-	Jmol._doAjax = function(url, postOut, dataOut) {
+	Jmol.doAjax = function(url, postOut, dataOut) {
 		// called by org.jmol.awtjs2d.JmolURLConnection.doAjax()
 		url = url.toString();
 		if (dataOut) {
@@ -1187,8 +1187,14 @@ Jmol = (function(document) {
 			: filename.indexOf(".gif") >= 0 ? "image/gif" 
 			: filename.indexOf(".jpg") >= 0 ? "image/jpg" : ""));
 		var isString = (typeof data == "string");
+		
+	if (isString && data.indexOf(";base64,") >= 0) {
+	  data = data.split(";base64,")[1];
+	} else {	
    	data = (JU || J.util).Base64.getBase64(isString ? data.getBytes("UTF-8") : data).toString();
+   	}
 		encoding || (encoding = "base64");
+		
 		var url = Jmol._serverUrl;
 		url && url.indexOf("your.server") >= 0 && (url = "");
 		if (Jmol._useDataURI || !url) {
@@ -1665,7 +1671,7 @@ Jmol = (function(document) {
 		return (x == undefined ? null : [Math.round(x), Math.round(y), Jmol._jsGetMouseModifiers(ev)]);
 	}
 
-  Jmol._setCursor = function(applet, c) {
+  Jmol.setCursor = function(applet, c) {
     if (applet._isJava || applet._readingLocal)
       return;
     var curs;
@@ -1802,7 +1808,7 @@ Jmol = (function(document) {
       if (canvas.isdragging && (!ui || !ui.handleJSEvent(canvas, 506, ev))) {}
 			canvas.applet._processEvent((canvas.isDragging ? 506 : 503), xym); // java.awt.Event.MOUSE_DRAG : java.awt.Event.MOUSE_MOVE
 			return !!ui;
-		}
+}
 		
 		Jmol.$bind(canvas, 'DOMMouseScroll mousewheel', function(ev) { // Zoom
       if (doIgnore(ev))
